@@ -13,7 +13,6 @@ from pycatia.system_interfaces.setting_controller import SettingController
 
 
 class DraftingSettingAtt(SettingController):
-
     """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -35,7 +34,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att = com_object
 
     @property
-    def create_new_sheet_from(self):
+    def create_new_sheet_from(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -43,21 +42,22 @@ class DraftingSettingAtt(SettingController):
                 | 
                 |     Returns the CreateNewSheetFrom parameter.
 
-        :return: enum cat_drw_new_sheet_from
+        :return: int
+        :rtype: int
         """
 
         return self.drafting_setting_att.CreateNewSheetFrom
 
     @create_new_sheet_from.setter
-    def create_new_sheet_from(self, value):
+    def create_new_sheet_from(self, value: int):
         """
-        :param enum cat_drw_new_sheet_from value:
+        :param int value:
         """
 
         self.drafting_setting_att.CreateNewSheetFrom = value
 
     @property
-    def display_reset_button(self):
+    def display_reset_button(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -66,12 +66,13 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the DisplayResetButton parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.DisplayResetButton
 
     @display_reset_button.setter
-    def display_reset_button(self, value):
+    def display_reset_button(self, value: bool):
         """
         :param bool value:
         """
@@ -79,7 +80,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.DisplayResetButton = value
 
     @property
-    def lock_user_default(self):
+    def lock_user_default(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -88,12 +89,13 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the LockUserDefault parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.LockUserDefault
 
     @lock_user_default.setter
-    def lock_user_default(self, value):
+    def lock_user_default(self, value: bool):
         """
         :param bool value:
         """
@@ -101,7 +103,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.LockUserDefault = value
 
     @property
-    def prevent_background_access(self):
+    def prevent_background_access(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -110,12 +112,13 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the PreventBackgroundAccess parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.PreventBackgroundAccess
 
     @prevent_background_access.setter
-    def prevent_background_access(self, value):
+    def prevent_background_access(self, value: bool):
         """
         :param bool value:
         """
@@ -123,7 +126,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.PreventBackgroundAccess = value
 
     @property
-    def prevent_dim_driving3_d_cstr(self):
+    def prevent_dim_driving_3d_cstr(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -132,12 +135,13 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the PreventDimDriving3DCstr parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.PreventDimDriving3DCstr
 
-    @prevent_dim_driving3_d_cstr.setter
-    def prevent_dim_driving3_d_cstr(self, value):
+    @prevent_dim_driving_3d_cstr.setter
+    def prevent_dim_driving_3d_cstr(self, value: bool):
         """
         :param bool value:
         """
@@ -145,7 +149,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.PreventDimDriving3DCstr = value
 
     @property
-    def prevent_file_new(self):
+    def prevent_file_new(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -159,7 +163,7 @@ class DraftingSettingAtt(SettingController):
         return self.drafting_setting_att.PreventFileNew
 
     @prevent_file_new.setter
-    def prevent_file_new(self, value):
+    def prevent_file_new(self, value: bool):
         """
         :param bool value:
         """
@@ -167,7 +171,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.PreventFileNew = value
 
     @property
-    def prevent_gen_view_style(self):
+    def prevent_gen_view_style(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -176,12 +180,13 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the PreventGenViewStyle parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.PreventGenViewStyle
 
     @prevent_gen_view_style.setter
-    def prevent_gen_view_style(self, value):
+    def prevent_gen_view_style(self, value: bool):
         """
         :param bool value:
         """
@@ -189,7 +194,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.PreventGenViewStyle = value
 
     @property
-    def prevent_set_as_default(self):
+    def prevent_set_as_default(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -198,12 +203,13 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the PreventSetAsDefault parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.PreventSetAsDefault
 
     @prevent_set_as_default.setter
-    def prevent_set_as_default(self, value):
+    def prevent_set_as_default(self, value: bool):
         """
         :param bool value:
         """
@@ -211,7 +217,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.PreventSetAsDefault = value
 
     @property
-    def prevent_switch_standard(self):
+    def prevent_switch_standard(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -220,12 +226,13 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the PreventSwitchStandard parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.PreventSwitchStandard
 
     @prevent_switch_standard.setter
-    def prevent_switch_standard(self, value):
+    def prevent_switch_standard(self, value: bool):
         """
         :param bool value:
         """
@@ -233,7 +240,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.PreventSwitchStandard = value
 
     @property
-    def prevent_true_dimension_creation(self):
+    def prevent_true_dimension_creation(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -242,12 +249,13 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the PreventTrueDimensionCreation parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.PreventTrueDimensionCreation
 
     @prevent_true_dimension_creation.setter
-    def prevent_true_dimension_creation(self, value):
+    def prevent_true_dimension_creation(self, value: bool):
         """
         :param bool value:
         """
@@ -255,7 +263,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.PreventTrueDimensionCreation = value
 
     @property
-    def prevent_update_standard(self):
+    def prevent_update_standard(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -264,12 +272,13 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the PreventUpdateStandard parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.PreventUpdateStandard
 
     @prevent_update_standard.setter
-    def prevent_update_standard(self, value):
+    def prevent_update_standard(self, value: bool):
         """
         :param bool value:
         """
@@ -277,7 +286,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.PreventUpdateStandard = value
 
     @property
-    def prevent_view_geom_upgrade(self):
+    def prevent_view_geom_upgrade(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -291,7 +300,7 @@ class DraftingSettingAtt(SettingController):
         return self.drafting_setting_att.PreventViewGeomUpgrade
 
     @prevent_view_geom_upgrade.setter
-    def prevent_view_geom_upgrade(self, value):
+    def prevent_view_geom_upgrade(self, value: bool):
         """
         :param bool value:
         """
@@ -299,7 +308,7 @@ class DraftingSettingAtt(SettingController):
         self.drafting_setting_att.PreventViewGeomUpgrade = value
 
     @property
-    def use_style_create_objects(self):
+    def use_style_create_objects(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -308,19 +317,20 @@ class DraftingSettingAtt(SettingController):
                 |     Returns the UseStyleCreateObjects parameter.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.drafting_setting_att.UseStyleCreateObjects
 
     @use_style_create_objects.setter
-    def use_style_create_objects(self, value):
+    def use_style_create_objects(self, value: bool):
         """
         :param bool value:
         """
 
         self.drafting_setting_att.UseStyleCreateObjects = value
 
-    def get_create_new_sheet_from_info(self, io_admin_level, io_locked):
+    def get_create_new_sheet_from_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -351,10 +361,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetCreateNewSheetFromInfo(io_admin_level, io_locked)
 
-    def get_display_reset_button_info(self, io_admin_level, io_locked):
+    def get_display_reset_button_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -385,10 +396,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetDisplayResetButtonInfo(io_admin_level, io_locked)
 
-    def get_lock_user_default_info(self, io_admin_level, io_locked):
+    def get_lock_user_default_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -419,10 +431,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetLockUserDefaultInfo(io_admin_level, io_locked)
 
-    def get_prevent_background_access_info(self, io_admin_level, io_locked):
+    def get_prevent_background_access_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -453,10 +466,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetPreventBackgroundAccessInfo(io_admin_level, io_locked)
 
-    def get_prevent_dim_driving3_d_cstr_info(self, io_admin_level, io_locked):
+    def get_prevent_dim_driving_3d_cstr_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -487,10 +501,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetPreventDimDriving3DCstrInfo(io_admin_level, io_locked)
 
-    def get_prevent_file_new_info(self, io_admin_level, io_locked, o_modified):
+    def get_prevent_file_new_info(self, io_admin_level: str, io_locked: str, o_modified: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -523,6 +538,7 @@ class DraftingSettingAtt(SettingController):
         :param str io_locked:
         :param bool o_modified:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.GetPreventFileNewInfo(io_admin_level, io_locked, o_modified)
         # # # # Autogenerated comment: 
@@ -541,7 +557,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_prevent_gen_view_style_info(self, io_admin_level, io_locked):
+    def get_prevent_gen_view_style_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -572,10 +588,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetPreventGenViewStyleInfo(io_admin_level, io_locked)
 
-    def get_prevent_set_as_default_info(self, io_admin_level, io_locked):
+    def get_prevent_set_as_default_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -606,10 +623,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetPreventSetAsDefaultInfo(io_admin_level, io_locked)
 
-    def get_prevent_switch_standard_info(self, io_admin_level, io_locked):
+    def get_prevent_switch_standard_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -640,10 +658,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetPreventSwitchStandardInfo(io_admin_level, io_locked)
 
-    def get_prevent_true_dimension_creation_info(self, io_admin_level, io_locked):
+    def get_prevent_true_dimension_creation_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -675,10 +694,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetPreventTrueDimensionCreationInfo(io_admin_level, io_locked)
 
-    def get_prevent_update_standard_info(self, io_admin_level, io_locked):
+    def get_prevent_update_standard_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -709,10 +729,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetPreventUpdateStandardInfo(io_admin_level, io_locked)
 
-    def get_prevent_view_geom_upgrade_info(self, io_admin_level, io_locked):
+    def get_prevent_view_geom_upgrade_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -743,10 +764,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetPreventViewGeomUpgradeInfo(io_admin_level, io_locked)
 
-    def get_use_style_create_objects_info(self, io_admin_level, io_locked):
+    def get_use_style_create_objects_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -777,10 +799,11 @@ class DraftingSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.drafting_setting_att.GetUseStyleCreateObjectsInfo(io_admin_level, io_locked)
 
-    def set_create_new_sheet_from_lock(self, i_locked):
+    def set_create_new_sheet_from_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -801,6 +824,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetCreateNewSheetFromLock(i_locked)
         # # # # Autogenerated comment: 
@@ -819,7 +843,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_display_reset_button_lock(self, i_locked):
+    def set_display_reset_button_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -840,6 +864,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetDisplayResetButtonLock(i_locked)
         # # # # Autogenerated comment: 
@@ -858,7 +883,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_lock_user_default_lock(self, i_locked):
+    def set_lock_user_default_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -879,6 +904,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetLockUserDefaultLock(i_locked)
         # # # # Autogenerated comment: 
@@ -897,7 +923,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_prevent_background_access_lock(self, i_locked):
+    def set_prevent_background_access_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -918,6 +944,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetPreventBackgroundAccessLock(i_locked)
         # # # # Autogenerated comment: 
@@ -936,7 +963,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_prevent_dim_driving3_d_cstr_lock(self, i_locked):
+    def set_prevent_dim_driving_3d_cstr_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -957,6 +984,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetPreventDimDriving3DCstrLock(i_locked)
         # # # # Autogenerated comment: 
@@ -975,7 +1003,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_prevent_file_new_lock(self, i_locked):
+    def set_prevent_file_new_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -996,6 +1024,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetPreventFileNewLock(i_locked)
         # # # # Autogenerated comment: 
@@ -1014,7 +1043,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_prevent_gen_view_style_lock(self, i_locked):
+    def set_prevent_gen_view_style_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -1035,6 +1064,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetPreventGenViewStyleLock(i_locked)
         # # # # Autogenerated comment: 
@@ -1053,7 +1083,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_prevent_set_as_default_lock(self, i_locked):
+    def set_prevent_set_as_default_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -1074,6 +1104,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetPreventSetAsDefaultLock(i_locked)
         # # # # Autogenerated comment: 
@@ -1092,7 +1123,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_prevent_switch_standard_lock(self, i_locked):
+    def set_prevent_switch_standard_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -1113,6 +1144,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetPreventSwitchStandardLock(i_locked)
         # # # # Autogenerated comment: 
@@ -1131,7 +1163,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_prevent_true_dimension_creation_lock(self, i_locked):
+    def set_prevent_true_dimension_creation_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -1153,6 +1185,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetPreventTrueDimensionCreationLock(i_locked)
         # # # # Autogenerated comment: 
@@ -1171,7 +1204,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_prevent_update_standard_lock(self, i_locked):
+    def set_prevent_update_standard_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -1192,6 +1225,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetPreventUpdateStandardLock(i_locked)
         # # # # Autogenerated comment: 
@@ -1210,7 +1244,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_prevent_view_geom_upgrade_lock(self, i_locked):
+    def set_prevent_view_geom_upgrade_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -1249,7 +1283,7 @@ class DraftingSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_use_style_create_objects_lock(self, i_locked):
+    def set_use_style_create_objects_lock(self, i_locked: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -1270,6 +1304,7 @@ class DraftingSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.drafting_setting_att.SetUseStyleCreateObjectsLock(i_locked)
         # # # # Autogenerated comment: 
@@ -1289,4 +1324,4 @@ class DraftingSettingAtt(SettingController):
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
-        return f'DraftingSettingAtt(name="{ self.name }")'
+        return f'DraftingSettingAtt(name="{self.name}")'
