@@ -36,7 +36,7 @@ class DrawingDimExtLine(AnyObject):
         self.drawing_dim_ext_line = com_object
 
     @property
-    def color(self):
+    def color(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -51,12 +51,13 @@ class DrawingDimExtLine(AnyObject):
                 |          oColorExtLine = MyExtLine.Color
 
         :return: int
+        :rtype: int
         """
 
         return self.drawing_dim_ext_line.Color
 
     @color.setter
-    def color(self, value):
+    def color(self, value: int):
         """
         :param int value:
         """
@@ -64,7 +65,7 @@ class DrawingDimExtLine(AnyObject):
         self.drawing_dim_ext_line.Color = value
 
     @property
-    def ext_line_slant(self):
+    def ext_line_slant(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -79,12 +80,13 @@ class DrawingDimExtLine(AnyObject):
                 |          oExtLineSlant = MyExtLine.ExtLineSlant
 
         :return: float
+        :rtype: float
         """
 
         return self.drawing_dim_ext_line.ExtLineSlant
 
     @ext_line_slant.setter
-    def ext_line_slant(self, value):
+    def ext_line_slant(self, value: float):
         """
         :param float value:
         """
@@ -92,7 +94,7 @@ class DrawingDimExtLine(AnyObject):
         self.drawing_dim_ext_line.ExtLineSlant = value
 
     @property
-    def ext_line_type(self):
+    def ext_line_type(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -107,12 +109,13 @@ class DrawingDimExtLine(AnyObject):
                 |          oExtLineType = MyExtLine.ExtLineType
 
         :return: int
+        :rtype: int
         """
 
         return self.drawing_dim_ext_line.ExtLineType
 
     @property
-    def thickness(self):
+    def thickness(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -127,19 +130,20 @@ class DrawingDimExtLine(AnyObject):
                 |          oThickExtLine = MyExtLine.Thickness
 
         :return: float
+        :rtype: float
         """
 
         return self.drawing_dim_ext_line.Thickness
 
     @thickness.setter
-    def thickness(self, value):
+    def thickness(self, value: float):
         """
         :param float value:
         """
 
         self.drawing_dim_ext_line.Thickness = value
 
-    def add_interrupt(self, i_index, i_two_points):
+    def add_interrupt(self, i_index: int, i_two_points: tuple) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -163,6 +167,7 @@ class DrawingDimExtLine(AnyObject):
         :param int i_index:
         :param tuple i_two_points:
         :return: None
+        :rtype: None
         """
         return self.drawing_dim_ext_line.AddInterrupt(i_index, i_two_points)
         # # # # Autogenerated comment: 
@@ -181,7 +186,7 @@ class DrawingDimExtLine(AnyObject):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_funnel(self, i_index, o_mode, o_angle, o_height, o_width):
+    def get_funnel(self, i_index: int, o_mode: int, o_angle: float, o_height: float, o_width: float) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -218,10 +223,11 @@ class DrawingDimExtLine(AnyObject):
         :param float o_height:
         :param float o_width:
         :return: None
+        :rtype: None
         """
         return self.drawing_dim_ext_line.GetFunnel(i_index, o_mode, o_angle, o_height, o_width)
 
-    def get_gap(self, i_index):
+    def get_gap(self, i_index: int) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -242,10 +248,11 @@ class DrawingDimExtLine(AnyObject):
 
         :param int i_index:
         :return: float
+        :rtype: float
         """
         return self.drawing_dim_ext_line.GetGap(i_index)
 
-    def get_geom_info(self, i_index, o_geom_infos):
+    def get_geom_info(self, i_index: int, o_geom_infos: tuple) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -270,6 +277,7 @@ class DrawingDimExtLine(AnyObject):
         :param int i_index:
         :param tuple o_geom_infos:
         :return: None
+        :rtype: None
         """
         return self.drawing_dim_ext_line.GetGeomInfo(i_index, o_geom_infos)
         # # # # Autogenerated comment: 
@@ -288,7 +296,7 @@ class DrawingDimExtLine(AnyObject):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_interrupt(self, i_index):
+    def get_interrupt(self, i_index: int) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -311,10 +319,11 @@ class DrawingDimExtLine(AnyObject):
 
         :param int i_index:
         :return: int
+        :rtype: int
         """
         return self.drawing_dim_ext_line.GetInterrupt(i_index)
 
-    def get_overrun(self, i_index):
+    def get_overrun(self, i_index: int) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -335,10 +344,11 @@ class DrawingDimExtLine(AnyObject):
 
         :param int i_index:
         :return: float
+        :rtype: float
         """
         return self.drawing_dim_ext_line.GetOverrun(i_index)
 
-    def get_visibility(self, i_index):
+    def get_visibility(self, i_index: int) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -359,10 +369,11 @@ class DrawingDimExtLine(AnyObject):
 
         :param int i_index:
         :return: int
+        :rtype: int
         """
         return self.drawing_dim_ext_line.GetVisibility(i_index)
 
-    def remove_interrupt(self, i_index):
+    def remove_interrupt(self, i_index: int) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -382,10 +393,11 @@ class DrawingDimExtLine(AnyObject):
 
         :param int i_index:
         :return: None
+        :rtype: None
         """
         return self.drawing_dim_ext_line.RemoveInterrupt(i_index)
 
-    def set_funnel(self, i_index, i_mode, i_angle, i_height, i_width):
+    def set_funnel(self, i_index: int, i_mode: int, i_angle: float, i_height: float, i_width: float) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -422,10 +434,11 @@ class DrawingDimExtLine(AnyObject):
         :param float i_height:
         :param float i_width:
         :return: None
+        :rtype: None
         """
         return self.drawing_dim_ext_line.SetFunnel(i_index, i_mode, i_angle, i_height, i_width)
 
-    def set_gap(self, i_index, i_gap):
+    def set_gap(self, i_index: int, i_gap: float) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -448,10 +461,11 @@ class DrawingDimExtLine(AnyObject):
         :param int i_index:
         :param float i_gap:
         :return: None
+        :rtype: None
         """
         return self.drawing_dim_ext_line.SetGap(i_index, i_gap)
 
-    def set_overrun(self, i_index, i_overrun):
+    def set_overrun(self, i_index: int, i_overrun: float) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -474,10 +488,11 @@ class DrawingDimExtLine(AnyObject):
         :param int i_index:
         :param float i_overrun:
         :return: None
+        :rtype: None
         """
         return self.drawing_dim_ext_line.SetOverrun(i_index, i_overrun)
 
-    def set_visibility(self, i_index, i_extline_visibility):
+    def set_visibility(self, i_index: int, i_extline_visibility: int) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -501,6 +516,7 @@ class DrawingDimExtLine(AnyObject):
         :param int i_index:
         :param int i_extline_visibility:
         :return: None
+        :rtype: None
         """
         return self.drawing_dim_ext_line.SetVisibility(i_index, i_extline_visibility)
 
