@@ -11,6 +11,7 @@
 
 from pycatia.drafting_interfaces.drawing_picture import DrawingPicture
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class DrawingPictures(Collection):
@@ -34,7 +35,7 @@ class DrawingPictures(Collection):
         super().__init__(com_object, child_object=DrawingPicture)
         self.drawing_pictures = com_object
 
-    def add(self, i_drawing_picture_path, i_position_x, i_position_y):
+    def add(self, i_drawing_picture_path: str, i_position_x: float, i_position_y: float) -> DrawingPicture:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -73,10 +74,11 @@ class DrawingPictures(Collection):
         :param float i_position_x:
         :param float i_position_y:
         :return: DrawingPicture
+        :rtype: DrawingPicture
         """
         return DrawingPicture(self.drawing_pictures.Add(i_drawing_picture_path, i_position_x, i_position_y))
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> DrawingPicture:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -111,12 +113,13 @@ class DrawingPictures(Collection):
                 |      Dim ThisDrawingPicture As DrawingPicture
                 |      Set ThisDrawingPicture = MyView.Pictures.Item(2)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: DrawingPicture
+        :rtype: DrawingPicture
         """
         return DrawingPicture(self.drawing_pictures.Item(i_index))
 
-    def remove(self, i_index):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -146,25 +149,11 @@ class DrawingPictures(Collection):
                 |      Set MyView  = MySheet.Views.ActiveView
                 |      MyView.Pictures.Remove(3)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
         return self.drawing_pictures.Remove(i_index)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove'
-        # # vba_code = """
-        # # Public Function remove(drawing_pictures)
-        # #     Dim iIndex (2)
-        # #     drawing_pictures.Remove iIndex
-        # #     remove = iIndex
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
         return f'DrawingPictures(name="{self.name}")'
