@@ -1,6 +1,6 @@
 #! usr/bin/python3.6
 """
-    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
+    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
     .. warning::
         The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
@@ -16,7 +16,7 @@ from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
 class HybridShapeExtractMulti(HybridShape):
     """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
                 |     System.IDispatch
@@ -42,10 +42,11 @@ class HybridShapeExtractMulti(HybridShape):
         super().__init__(com_object)
         self.hybrid_shape_extract_multi = com_object
 
-    def add_constraint(self, i_constraint, i_type, i_complementaire, i_is_federated, i_crvtre_thsld, i_pos):
+    def add_constraint(self, i_constraint: Reference, i_type: int, i_complementaire: bool, i_is_federated: bool,
+                       i_crvtre_thsld: float, i_pos: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddConstraint(Reference iConstraint,
                 | long iType,
                 | boolean iComplementaire,
@@ -94,15 +95,10 @@ class HybridShapeExtractMulti(HybridShape):
         :param float i_crvtre_thsld:
         :param int i_pos:
         :return: None
+        :rtype: None
         """
-        return self.hybrid_shape_extract_multi.AddConstraint(
-            i_constraint.com_object,
-            i_type,
-            i_complementaire,
-            i_is_federated,
-            i_crvtre_thsld,
-            i_pos
-        )
+        return self.hybrid_shape_extract_multi.AddConstraint(i_constraint.com_object, i_type, i_complementaire,
+                                                             i_is_federated, i_crvtre_thsld, i_pos)
         # # # # Autogenerated comment: 
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
@@ -119,20 +115,12 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def add_constraint_tolerant(
-            self,
-            i_constraint,
-            i_type,
-            i_complementaire,
-            i_is_federated,
-            i_distre_thsld,
-            i_angtre_thsld,
-            i_crvtre_thsld,
-            i_pos
-    ):
+    def add_constraint_tolerant(self, i_constraint: Reference, i_type: int, i_complementaire: bool,
+                                i_is_federated: bool, i_distre_thsld: float, i_angtre_thsld: float,
+                                i_crvtre_thsld: float, i_pos: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddConstraintTolerant(Reference iConstraint,
                 | long iType,
                 | boolean iComplementaire,
@@ -190,17 +178,11 @@ class HybridShapeExtractMulti(HybridShape):
         :param float i_crvtre_thsld:
         :param int i_pos:
         :return: None
+        :rtype: None
         """
-        return self.hybrid_shape_extract_multi.AddConstraintTolerant(
-            i_constraint.com_object,
-            i_type,
-            i_complementaire,
-            i_is_federated,
-            i_distre_thsld,
-            i_angtre_thsld,
-            i_crvtre_thsld,
-            i_pos
-        )
+        return self.hybrid_shape_extract_multi.AddConstraintTolerant(i_constraint.com_object, i_type, i_complementaire,
+                                                                     i_is_federated, i_distre_thsld, i_angtre_thsld,
+                                                                     i_crvtre_thsld, i_pos)
         # # # # Autogenerated comment: 
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
@@ -217,10 +199,10 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_angular_threshold(self, i_pos):
+    def get_angular_threshold(self, i_pos: int) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetAngularThreshold(long iPos) As double
                 | 
                 |     Returns the AngularThreshold of the list of constraints at specified
@@ -236,13 +218,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: float
+        :rtype: float
         """
         return self.hybrid_shape_extract_multi.GetAngularThreshold(i_pos)
 
-    def get_angular_threshold_activity(self, i_pos):
+    def get_angular_threshold_activity(self, i_pos: int) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetAngularThresholdActivity(long iPos) As boolean
                 | 
                 |     Returns the AngularThresholdActivity of the list of constraints at
@@ -258,13 +241,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_extract_multi.GetAngularThresholdActivity(i_pos)
 
-    def get_complementary_extract_multi(self, i_pos):
+    def get_complementary_extract_multi(self, i_pos: int) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetComplementaryExtractMulti(long iPos) As boolean
                 | 
                 |     Returns the Complementary flag checked/unchecked of the list of constraints
@@ -280,13 +264,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_extract_multi.GetComplementaryExtractMulti(i_pos)
 
-    def get_curvature_threshold(self, i_pos):
+    def get_curvature_threshold(self, i_pos: int) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetCurvatureThreshold(long iPos) As double
                 | 
                 |     Returns the CurvatureThreshold of the list of constraints at specified
@@ -302,13 +287,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: float
+        :rtype: float
         """
         return self.hybrid_shape_extract_multi.GetCurvatureThreshold(i_pos)
 
-    def get_curvature_threshold_activity(self, i_pos):
+    def get_curvature_threshold_activity(self, i_pos: int) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetCurvatureThresholdActivity(long iPos) As boolean
                 | 
                 |     Returns the CurvatureThresholdActivity of the list of constraints at
@@ -324,13 +310,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_extract_multi.GetCurvatureThresholdActivity(i_pos)
 
-    def get_distance_threshold(self, i_pos):
+    def get_distance_threshold(self, i_pos: int) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDistanceThreshold(long iPos) As double
                 | 
                 |     Returns the DistanceThreshold of the list of constraints at specified
@@ -346,13 +333,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: float
+        :rtype: float
         """
         return self.hybrid_shape_extract_multi.GetDistanceThreshold(i_pos)
 
-    def get_distance_threshold_activity(self, i_pos):
+    def get_distance_threshold_activity(self, i_pos: int) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDistanceThresholdActivity(long iPos) As boolean
                 | 
                 |     Returns the DistanceThresholdActivity of the list of constraints at
@@ -368,13 +356,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_extract_multi.GetDistanceThresholdActivity(i_pos)
 
-    def get_element(self, i_pos):
+    def get_element(self, i_pos: int) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetElement(long iPos) As Reference
                 | 
                 |     Returns the sub element used as init for the propagation.
@@ -392,13 +381,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: Reference
+        :rtype: Reference
         """
         return Reference(self.hybrid_shape_extract_multi.GetElement(i_pos))
 
-    def get_is_federated(self, i_pos):
+    def get_is_federated(self, i_pos: int) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetIsFederated(long iPos) As boolean
                 | 
                 |     Returns the IsFederated flag checked/unchecked of the list of constraints
@@ -414,13 +404,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_extract_multi.GetIsFederated(i_pos)
 
-    def get_list_of_constraints(self, o_list_of_extracted_constraints):
+    def get_list_of_constraints(self, o_list_of_extracted_constraints: tuple) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetListOfConstraints(CATSafeArrayVariant
                 | oListOfExtractedConstraints)
                 | 
@@ -452,6 +443,7 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param tuple o_list_of_extracted_constraints:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.GetListOfConstraints(o_list_of_extracted_constraints)
         # # # # Autogenerated comment: 
@@ -470,10 +462,10 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_nb_constraints(self, o_nb_constraints):
+    def get_nb_constraints(self, o_nb_constraints: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetNbConstraints(long oNbConstraints)
                 | 
                 |     Returns number of constraints in the list of Extracted
@@ -495,13 +487,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int o_nb_constraints:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.GetNbConstraints(o_nb_constraints)
 
-    def get_propagation_type(self, i_pos):
+    def get_propagation_type(self, i_pos: int) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetPropagationType(long iPos) As long
                 | 
                 |     Returns the type of propagation of the list of constraints at specified
@@ -524,13 +517,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: int
+        :rtype: int
         """
         return self.hybrid_shape_extract_multi.GetPropagationType(i_pos)
 
-    def get_support(self, i_pos):
+    def get_support(self, i_pos: int) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetSupport(long iPos) As Reference
                 | 
                 |     Returns the support of the list of constraints at specified
@@ -543,13 +537,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_pos:
         :return: Reference
+        :rtype: Reference
         """
         return Reference(self.hybrid_shape_extract_multi.GetSupport(i_pos))
 
-    def remove_element(self, i_position):
+    def remove_element(self, i_position: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveElement(long iPosition)
                 | 
                 |     Removes the body to be extracted from the list of constraints at specified
@@ -569,13 +564,14 @@ class HybridShapeExtractMulti(HybridShape):
 
         :param int i_position:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.RemoveElement(i_position)
 
-    def replace_element(self, i_extract_to_replace, i_new_extract, i_pos):
+    def replace_element(self, i_extract_to_replace: Reference, i_new_extract: Reference, i_pos: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub ReplaceElement(Reference iExtractToReplace,
                 | Reference iNewExtract,
                 | long iPos)
@@ -606,12 +602,10 @@ class HybridShapeExtractMulti(HybridShape):
         :param Reference i_new_extract:
         :param int i_pos:
         :return: None
+        :rtype: None
         """
-        return self.hybrid_shape_extract_multi.ReplaceElement(
-            i_extract_to_replace.com_object,
-            i_new_extract.com_object,
-            i_pos
-        )
+        return self.hybrid_shape_extract_multi.ReplaceElement(i_extract_to_replace.com_object, i_new_extract.com_object,
+                                                              i_pos)
         # # # # Autogenerated comment: 
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
@@ -628,10 +622,10 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_angular_threshold(self, i_pos, i_angtre_thsld):
+    def set_angular_threshold(self, i_pos: int, i_angtre_thsld: float) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAngularThreshold(long iPos,
                 | double iAngtreThsld)
                 | 
@@ -649,13 +643,14 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param float i_angtre_thsld:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetAngularThreshold(i_pos, i_angtre_thsld)
 
-    def set_angular_threshold_activity(self, i_pos, i_angtre_thsld_activity):
+    def set_angular_threshold_activity(self, i_pos: int, i_angtre_thsld_activity: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAngularThresholdActivity(long iPos,
                 | boolean iAngtreThsldActivity)
                 | 
@@ -674,6 +669,7 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param bool i_angtre_thsld_activity:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetAngularThresholdActivity(i_pos, i_angtre_thsld_activity)
         # # # # Autogenerated comment: 
@@ -692,10 +688,10 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_complementary_extract_multi(self, i_pos, i_complementaire):
+    def set_complementary_extract_multi(self, i_pos: int, i_complementaire: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetComplementaryExtractMulti(long iPos,
                 | boolean iComplementaire)
                 | 
@@ -714,6 +710,7 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param bool i_complementaire:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetComplementaryExtractMulti(i_pos, i_complementaire)
         # # # # Autogenerated comment: 
@@ -732,10 +729,10 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_curvature_threshold(self, i_pos, i_crvtre_thsld):
+    def set_curvature_threshold(self, i_pos: int, i_crvtre_thsld: float) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetCurvatureThreshold(long iPos,
                 | double iCrvtreThsld)
                 | 
@@ -753,13 +750,14 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param float i_crvtre_thsld:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetCurvatureThreshold(i_pos, i_crvtre_thsld)
 
-    def set_curvature_threshold_activity(self, i_pos, i_crvtre_thsld_activity):
+    def set_curvature_threshold_activity(self, i_pos: int, i_crvtre_thsld_activity: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetCurvatureThresholdActivity(long iPos,
                 | boolean iCrvtreThsldActivity)
                 | 
@@ -779,6 +777,7 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param bool i_crvtre_thsld_activity:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetCurvatureThresholdActivity(i_pos, i_crvtre_thsld_activity)
         # # # # Autogenerated comment: 
@@ -797,10 +796,10 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_distance_threshold(self, i_pos, i_distre_thsld):
+    def set_distance_threshold(self, i_pos: int, i_distre_thsld: float) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDistanceThreshold(long iPos,
                 | double iDistreThsld)
                 | 
@@ -818,13 +817,14 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param float i_distre_thsld:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetDistanceThreshold(i_pos, i_distre_thsld)
 
-    def set_distance_threshold_activity(self, i_pos, i_distre_thsld_activity):
+    def set_distance_threshold_activity(self, i_pos: int, i_distre_thsld_activity: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDistanceThresholdActivity(long iPos,
                 | boolean iDistreThsldActivity)
                 | 
@@ -844,6 +844,7 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param bool i_distre_thsld_activity:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetDistanceThresholdActivity(i_pos, i_distre_thsld_activity)
         # # # # Autogenerated comment: 
@@ -862,10 +863,10 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_element(self, i_pos, i_elem):
+    def set_element(self, i_pos: int, i_elem: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetElement(long iPos,
                 | Reference iElem)
                 | 
@@ -886,6 +887,7 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param Reference i_elem:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetElement(i_pos, i_elem.com_object)
         # # # # Autogenerated comment: 
@@ -904,10 +906,10 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_is_federated(self, i_pos, i_is_federated):
+    def set_is_federated(self, i_pos: int, i_is_federated: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetIsFederated(long iPos,
                 | boolean iIsFederated)
                 | 
@@ -926,6 +928,7 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param bool i_is_federated:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetIsFederated(i_pos, i_is_federated)
         # # # # Autogenerated comment: 
@@ -944,10 +947,10 @@ class HybridShapeExtractMulti(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_propagation_type(self, i_pos, i_type_propag):
+    def set_propagation_type(self, i_pos: int, i_type_propag: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetPropagationType(long iPos,
                 | long iTypePropag)
                 | 
@@ -973,13 +976,14 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param int i_type_propag:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetPropagationType(i_pos, i_type_propag)
 
-    def set_support(self, i_pos, i_support):
+    def set_support(self, i_pos: int, i_support: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetSupport(long iPos,
                 | Reference iSupport)
                 | 
@@ -994,6 +998,7 @@ class HybridShapeExtractMulti(HybridShape):
         :param int i_pos:
         :param Reference i_support:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_extract_multi.SetSupport(i_pos, i_support.com_object)
         # # # # Autogenerated comment: 
