@@ -1,6 +1,6 @@
 #! usr/bin/python3.6
 """
-    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
+    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
     .. warning::
         The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
@@ -18,7 +18,7 @@ from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
 class HybridShapeExtrude(HybridShape):
     """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
                 |     System.IDispatch
@@ -44,10 +44,10 @@ class HybridShapeExtrude(HybridShape):
         self.hybrid_shape_extrude = com_object
 
     @property
-    def begin_offset(self):
+    def begin_offset(self) -> Length:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property BeginOffset() As Length (Read Only)
                 | 
                 |     Role: To get_BeginOffset on the object. For surface extrude, if limit type
@@ -70,15 +70,16 @@ class HybridShapeExtrude(HybridShape):
                 |         HybridShapeFactory
 
         :return: Length
+        :rtype: Length
         """
 
         return Length(self.hybrid_shape_extrude.BeginOffset)
 
     @property
-    def context(self):
+    def context(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Context() As long
                 | 
                 |     Returns or sets the context on Extrude feature.
@@ -98,12 +99,13 @@ class HybridShapeExtrude(HybridShape):
                 |          Set oContext = Extrude1.Context
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_extrude.Context
 
     @context.setter
-    def context(self, value):
+    def context(self, value: int):
         """
         :param int value:
         """
@@ -111,10 +113,10 @@ class HybridShapeExtrude(HybridShape):
         self.hybrid_shape_extrude.Context = value
 
     @property
-    def direction(self):
+    def direction(self) -> HybridShapeDirection:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Direction() As HybridShapeDirection
                 | 
                 |     Role: To get_Direction on the object.
@@ -134,12 +136,13 @@ class HybridShapeExtrude(HybridShape):
                 |         HybridShapeFactory
 
         :return: HybridShapeDirection
+        :rtype: HybridShapeDirection
         """
 
         return HybridShapeDirection(self.hybrid_shape_extrude.Direction)
 
     @direction.setter
-    def direction(self, value):
+    def direction(self, value: HybridShapeDirection):
         """
         :param HybridShapeDirection value:
         """
@@ -147,10 +150,10 @@ class HybridShapeExtrude(HybridShape):
         self.hybrid_shape_extrude.Direction = value
 
     @property
-    def end_offset(self):
+    def end_offset(self) -> Length:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property EndOffset() As Length (Read Only)
                 | 
                 |     Role: To get_EndOffset on the object. For surface extrude, if limit type is
@@ -173,15 +176,16 @@ class HybridShapeExtrude(HybridShape):
                 |         HybridShapeFactory
 
         :return: Length
+        :rtype: Length
         """
 
         return Length(self.hybrid_shape_extrude.EndOffset)
 
     @property
-    def extruded_object(self):
+    def extruded_object(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ExtrudedObject() As Reference
                 | 
                 |     Role: To get_ExtrudedObject on the object.
@@ -201,12 +205,13 @@ class HybridShapeExtrude(HybridShape):
                 |         HybridShapeFactory
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_extrude.ExtrudedObject)
 
     @extruded_object.setter
-    def extruded_object(self, value):
+    def extruded_object(self, value: Reference):
         """
         :param Reference value:
         """
@@ -214,10 +219,10 @@ class HybridShapeExtrude(HybridShape):
         self.hybrid_shape_extrude.ExtrudedObject = value
 
     @property
-    def first_limit_type(self):
+    def first_limit_type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property FirstLimitType() As long
                 | 
                 |     Returns or sets the First limit type.
@@ -240,12 +245,13 @@ class HybridShapeExtrude(HybridShape):
                 |      Set oLim1Type = Extrude.FirstLimitType
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_extrude.FirstLimitType
 
     @first_limit_type.setter
-    def first_limit_type(self, value):
+    def first_limit_type(self, value: int):
         """
         :param int value:
         """
@@ -253,10 +259,10 @@ class HybridShapeExtrude(HybridShape):
         self.hybrid_shape_extrude.FirstLimitType = value
 
     @property
-    def first_upto_element(self):
+    def first_upto_element(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property FirstUptoElement() As Reference
                 | 
                 |     Returns or sets the First up-to element used to limit
@@ -270,12 +276,13 @@ class HybridShapeExtrude(HybridShape):
                 |          Set Lim1Elem = Extrude.FirstUptoElement
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_extrude.FirstUptoElement)
-
+    
     @first_upto_element.setter
-    def first_upto_element(self, value):
+    def first_upto_element(self, value: Reference):
         """
         :param Reference value:
         """
@@ -283,27 +290,28 @@ class HybridShapeExtrude(HybridShape):
         self.hybrid_shape_extrude.FirstUptoElement = value
 
     @property
-    def orientation(self):
+    def orientation(self) -> False:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Orientation(boolean iOrientation)
                 | 
-                |     Gets or sets orientation of the extrude. Orientation = TRUE :
-                |     The natural orientation is taken. = FALSE :
-                |     The opposite orientation is taken This example retrieves in IsInverted orientation of the
+                |     Gets or sets orientation of the extrude. 
+                |     Orientation = TRUE : The natural orientation is taken. = 
+                |     FALSE : The opposite orientation is taken This example retrieves in IsInverted orientation of the 
                 |     extrude for the Extrude hybrid shape feature.
                 | 
                 |      Dim IsInverted As boolean
                 |      IsInverted = Extrude.Orientation
 
         :return: False
+        :rtype: False
         """
 
         return None
 
     @orientation.setter
-    def orientation(self, value):
+    def orientation(self, value: False):
         """
         :param False value:
         """
@@ -311,10 +319,10 @@ class HybridShapeExtrude(HybridShape):
         self.hybrid_shape_extrude.Orientation = value
 
     @property
-    def second_limit_type(self):
+    def second_limit_type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property SecondLimitType() As long
                 | 
                 |     Returns or sets the Second limit type.
@@ -337,12 +345,13 @@ class HybridShapeExtrude(HybridShape):
                 |      Set oLim2Type = Extrude.SecondLimitType
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_extrude.SecondLimitType
 
     @second_limit_type.setter
-    def second_limit_type(self, value):
+    def second_limit_type(self, value: int):
         """
         :param int value:
         """
@@ -350,10 +359,10 @@ class HybridShapeExtrude(HybridShape):
         self.hybrid_shape_extrude.SecondLimitType = value
 
     @property
-    def second_upto_element(self):
+    def second_upto_element(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property SecondUptoElement() As Reference
                 | 
                 |     Returns or sets the Second up-to element used to limit
@@ -367,12 +376,13 @@ class HybridShapeExtrude(HybridShape):
                 |          Set Lim2Elem = Extrude.SecondUptoElement
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_extrude.SecondUptoElement)
 
     @second_upto_element.setter
-    def second_upto_element(self, value):
+    def second_upto_element(self, value: Reference):
         """
         :param Reference value:
         """
@@ -380,10 +390,10 @@ class HybridShapeExtrude(HybridShape):
         self.hybrid_shape_extrude.SecondUptoElement = value
 
     @property
-    def symmetrical_extension(self):
+    def symmetrical_extension(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property SymmetricalExtension() As boolean
                 | 
                 |     Returns or Sets the Symmetrical Extension of Extrude (Limit 2 = -Limit 1).
@@ -391,15 +401,16 @@ class HybridShapeExtrude(HybridShape):
                 |     Parameters:
                 | 
                 |         iSym
-                |             Symmetry flag
+                |             Symetry flag
 
         :return: bool
+        :rtype: bool
         """
 
         return self.hybrid_shape_extrude.SymmetricalExtension
 
     @symmetrical_extension.setter
-    def symmetrical_extension(self, value):
+    def symmetrical_extension(self, value: bool):
         """
         :param bool value:
         """
