@@ -1,6 +1,6 @@
 #! usr/bin/python3.6
 """
-    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
+    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
     .. warning::
         The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
@@ -18,7 +18,7 @@ from pycatia.knowledge_interfaces.length import Length
 class HybridShapeLinePtDir(Line):
     """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
                 |     System.IDispatch
@@ -52,10 +52,10 @@ class HybridShapeLinePtDir(Line):
         self.hybrid_shape_line_pt_dir = com_object
 
     @property
-    def begin_offset(self):
+    def begin_offset(self) -> Length:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property BeginOffset() As Length (Read Only)
                 | 
                 |     Returns the start length of the line.
@@ -69,15 +69,16 @@ class HybridShapeLinePtDir(Line):
                 |          Set oStart = LinePtDir.BeginOffset
 
         :return: Length
+        :rtype: Length
         """
 
         return Length(self.hybrid_shape_line_pt_dir.BeginOffset)
 
     @property
-    def dir(self):
+    def dir(self) -> HybridShapeDirection:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Dir() As HybridShapeDirection
                 | 
                 |     Returns or Sets the direction of the line.
@@ -90,12 +91,13 @@ class HybridShapeLinePtDir(Line):
                 |          Set oDir = LinePtDir.Dir
 
         :return: HybridShapeDirection
+        :rtype: HybridShapeDirection
         """
 
         return HybridShapeDirection(self.hybrid_shape_line_pt_dir.Dir)
 
     @dir.setter
-    def dir(self, value):
+    def dir(self, value: HybridShapeDirection):
         """
         :param HybridShapeDirection value:
         """
@@ -103,10 +105,10 @@ class HybridShapeLinePtDir(Line):
         self.hybrid_shape_line_pt_dir.Dir = value
 
     @property
-    def end_offset(self):
+    def end_offset(self) -> Length:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property EndOffset() As Length (Read Only)
                 | 
                 |     Returns the end length of the line.
@@ -120,22 +122,23 @@ class HybridShapeLinePtDir(Line):
                 |          Set oEnd = LinePtDir.EndOffset
 
         :return: Length
+        :rtype: Length
         """
 
         return Length(self.hybrid_shape_line_pt_dir.EndOffset)
 
     @property
-    def orientation(self):
+    def orientation(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Orientation() As long
                 | 
                 |     Returns or Sets the line orientation.
                 |     Orientation allows to reverse the line direction from the reference
                 |     point.
-                |     For a line of L length, it is the same as creating this line with -L length : Orientation :
-                |     can be 1 or -1
+                |     For a line of L length, it is the same as creating this line with -L length :
+                |     Orientation : can be 1 or -1
                 | 
                 |     Example:
                 |         This example retrieves in oOrientation the starting length for the
@@ -145,12 +148,13 @@ class HybridShapeLinePtDir(Line):
                 |          Set oOrientation = LinePtDir.Orientation
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_line_pt_dir.Orientation
 
     @orientation.setter
-    def orientation(self, value):
+    def orientation(self, value: int):
         """
         :param int value:
         """
@@ -158,10 +162,10 @@ class HybridShapeLinePtDir(Line):
         self.hybrid_shape_line_pt_dir.Orientation = value
 
     @property
-    def point(self):
+    def point(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Point() As Reference
                 | 
                 |     Returns or Sets the starting point of the line.
@@ -175,12 +179,13 @@ class HybridShapeLinePtDir(Line):
                 |          Set oPoint = LinePtDir.Point
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_line_pt_dir.Point)
 
     @point.setter
-    def point(self, value):
+    def point(self, value: Reference):
         """
         :param Reference value:
         """
@@ -188,10 +193,10 @@ class HybridShapeLinePtDir(Line):
         self.hybrid_shape_line_pt_dir.Point = value
 
     @property
-    def support(self):
+    def support(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Support() As Reference
                 | 
                 |     Returns or Sets the supporting surface.
@@ -207,22 +212,23 @@ class HybridShapeLinePtDir(Line):
                 |          Set oSurface = LinePtDir.Surface
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_line_pt_dir.Support)
 
     @support.setter
-    def support(self, value):
+    def support(self, value: Reference):
         """
         :param Reference value:
         """
 
         self.hybrid_shape_line_pt_dir.Support = value
 
-    def get_length_type(self):
+    def get_length_type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetLengthType() As long
                 | 
                 |     Gets the length type Default is 0.
@@ -230,19 +236,20 @@ class HybridShapeLinePtDir(Line):
                 |     Parameters:
                 | 
                 |         oType
-                |             The length type = 0 : length - the line is limited by its extremities = 1 :
-                |             infinite - the line is infinite = 2 : infinite start point - the line is infinite on the
-                |             side of the start point = 3 : infinite end point - the line is infinite on the side of
-                |             the end point
+                |             The length type = 0 : length - the line is limited by its extremities =
+                |             1 : infinite - the line is infinite = 2 : infinite start point - the line is infinite on
+                |             the side of the start point = 3 : infinite end point - the line is infinite on the side
+                |             of the end point
 
         :return: int
+        :rtype: int
         """
         return self.hybrid_shape_line_pt_dir.GetLengthType()
 
-    def get_symmetrical_extension(self):
+    def get_symmetrical_extension(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetSymmetricalExtension() As boolean
                 | 
                 |     Gets whether the symmetrical extension of the line is
@@ -251,28 +258,30 @@ class HybridShapeLinePtDir(Line):
                 |     Parameters:
                 | 
                 |         oSym
-                |             Symmetry flag
+                |             Symetry flag
 
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_line_pt_dir.GetSymmetricalExtension()
 
-    def remove_support(self):
+    def remove_support(self) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveSupport()
                 | 
                 |     Removes the support surface.
 
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_line_pt_dir.RemoveSupport()
 
-    def set_length_type(self, i_type):
+    def set_length_type(self, i_type: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLengthType(long iType)
                 | 
                 |     Sets the length type Default is 0.
@@ -280,20 +289,21 @@ class HybridShapeLinePtDir(Line):
                 |     Parameters:
                 | 
                 |         iType
-                |             The length type = 0 : length - the line is limited by its extremities = 1 :
-                |             infinite - the line is infinite = 2 :
-                |             infinite start point - the line is infinite on the side of the start point = 3 :
-                |             infinite end point - the line is infinite on the side of the end point
+                |             The length type = 0 : length - the line is limited by its extremities =
+                |             1 : infinite - the line is infinite = 2 : infinite start point - the line is infinite on
+                |             the side of the start point = 3 : infinite end point - the line is infinite on the side
+                |             of the end point
 
         :param int i_type:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_line_pt_dir.SetLengthType(i_type)
 
-    def set_symmetrical_extension(self, i_sym):
+    def set_symmetrical_extension(self, i_sym: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetSymmetricalExtension(boolean iSym)
                 | 
                 |     Sets the symmetrical extension of the line (start = -end).
@@ -301,10 +311,11 @@ class HybridShapeLinePtDir(Line):
                 |     Parameters:
                 | 
                 |         iSym
-                |             Symmetry flag
+                |             Symetry flag
 
         :param bool i_sym:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_line_pt_dir.SetSymmetricalExtension(i_sym)
         # # # # Autogenerated comment: 
