@@ -1,6 +1,6 @@
 #! usr/bin/python3.6
 """
-    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
+    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
     .. warning::
         The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
@@ -14,9 +14,10 @@ from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
 
 
 class HybridShapeSpine(HybridShape):
+
     """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
                 |     System.IDispatch
@@ -40,22 +41,23 @@ class HybridShapeSpine(HybridShape):
         self.hybrid_shape_spine = com_object
 
     @property
-    def orientation(self):
+    def orientation(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Orientation() As long
                 | 
                 |     Gets or Sets the orientation. Orientation by reference with the normal to
                 |     the first section/plane
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_spine.Orientation
 
     @orientation.setter
-    def orientation(self, value):
+    def orientation(self, value: int):
         """
         :param int value:
         """
@@ -63,31 +65,32 @@ class HybridShapeSpine(HybridShape):
         self.hybrid_shape_spine.Orientation = value
 
     @property
-    def start_point(self):
+    def start_point(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property StartPoint() As Reference
                 | 
                 |     Returns or sets the start point of the spine.
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_spine.StartPoint)
 
     @start_point.setter
-    def start_point(self, value):
+    def start_point(self, value: Reference):
         """
         :param Reference value:
         """
 
         self.hybrid_shape_spine.StartPoint = value
 
-    def add_guide(self, i_guide):
+    def add_guide(self, i_guide: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddGuide(Reference iGuide)
                 | 
                 |     Adds a guide to the spine curve.
@@ -99,6 +102,7 @@ class HybridShapeSpine(HybridShape):
 
         :param Reference i_guide:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_spine.AddGuide(i_guide.com_object)
         # # # # Autogenerated comment: 
@@ -117,10 +121,10 @@ class HybridShapeSpine(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def add_section(self, i_section):
+    def add_section(self, i_section: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddSection(Reference iSection)
                 | 
                 |     Adds a section or a plane to the spine curve.
@@ -136,6 +140,7 @@ class HybridShapeSpine(HybridShape):
 
         :param Reference i_section:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_spine.AddSection(i_section.com_object)
         # # # # Autogenerated comment: 
@@ -154,10 +159,10 @@ class HybridShapeSpine(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_guide(self, i_idx, op_ia_guide):
+    def get_guide(self, i_idx: int, op_ia_guide: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetGuide(long iIdx,
                 | Reference opIAGuide)
                 | 
@@ -173,6 +178,7 @@ class HybridShapeSpine(HybridShape):
         :param int i_idx:
         :param Reference op_ia_guide:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_spine.GetGuide(i_idx, op_ia_guide.com_object)
         # # # # Autogenerated comment: 
@@ -191,10 +197,10 @@ class HybridShapeSpine(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_number_of_guides(self):
+    def get_number_of_guides(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetNumberOfGuides() As long
                 | 
                 |     Retrieves number of guides in a spine curve.
@@ -205,13 +211,14 @@ class HybridShapeSpine(HybridShape):
                 |             Number of guides in a spine curve
 
         :return: int
+        :rtype: int
         """
         return self.hybrid_shape_spine.GetNumberOfGuides()
 
-    def get_number_of_sections(self):
+    def get_number_of_sections(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetNumberOfSections() As long
                 | 
                 |     Retrieves number of sections in a spine curve.
@@ -222,13 +229,14 @@ class HybridShapeSpine(HybridShape):
                 |             Number of sections in a spine curve
 
         :return: int
+        :rtype: int
         """
         return self.hybrid_shape_spine.GetNumberOfSections()
 
-    def get_section(self, i_idx, o_section):
+    def get_section(self, i_idx: int, o_section: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetSection(long iIdx,
                 | Reference oSection)
                 | 
@@ -244,6 +252,7 @@ class HybridShapeSpine(HybridShape):
         :param int i_idx:
         :param Reference o_section:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_spine.GetSection(i_idx, o_section.com_object)
         # # # # Autogenerated comment: 
@@ -262,10 +271,10 @@ class HybridShapeSpine(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def modify_guide_curve(self, ip_ia_guide, ip_ia_new_guide):
+    def modify_guide_curve(self, ip_ia_guide: Reference, ip_ia_new_guide: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub ModifyGuideCurve(Reference ipIAGuide,
                 | Reference ipIANewGuide)
                 | 
@@ -282,6 +291,7 @@ class HybridShapeSpine(HybridShape):
         :param Reference ip_ia_guide:
         :param Reference ip_ia_new_guide:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_spine.ModifyGuideCurve(ip_ia_guide.com_object, ip_ia_new_guide.com_object)
         # # # # Autogenerated comment: 
@@ -300,11 +310,11 @@ class HybridShapeSpine(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def modify_section_curve(self, ip_ia_section, ip_ia_new_section):
+    def modify_section_curve(self, ip_ia_section: Reference, ip_ia_new_section: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
-                | o Sub modifiesectionCurve(Reference ipIASection,
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
+                | o Sub ModifySectionCurve(Reference ipIASection,
                 | Reference ipIANewSection)
                 | 
                 |     Modifies a section or a plane from the spine curve.
@@ -320,8 +330,9 @@ class HybridShapeSpine(HybridShape):
         :param Reference ip_ia_section:
         :param Reference ip_ia_new_section:
         :return: None
+        :rtype: None
         """
-        return self.hybrid_shape_spine.modifiesectionCurve(ip_ia_section.com_object, ip_ia_new_section.com_object)
+        return self.hybrid_shape_spine.ModifySectionCurve(ip_ia_section.com_object, ip_ia_new_section.com_object)
         # # # # Autogenerated comment: 
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
@@ -330,7 +341,7 @@ class HybridShapeSpine(HybridShape):
         # # vba_code = """
         # # Public Function modify_section_curve(hybrid_shape_spine)
         # #     Dim ipIASection (2)
-        # #     hybrid_shape_spine.modifiesectionCurve ipIASection
+        # #     hybrid_shape_spine.ModifySectionCurve ipIASection
         # #     modify_section_curve = ipIASection
         # # End Function
         # # """
@@ -338,10 +349,10 @@ class HybridShapeSpine(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def remove_guide(self, i_guide):
+    def remove_guide(self, i_guide: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveGuide(Reference iGuide)
                 | 
                 |     Removes a guide from the spine curve.
@@ -353,6 +364,7 @@ class HybridShapeSpine(HybridShape):
 
         :param Reference i_guide:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_spine.RemoveGuide(i_guide.com_object)
         # # # # Autogenerated comment: 
@@ -371,10 +383,10 @@ class HybridShapeSpine(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def remove_section(self, i_section):
+    def remove_section(self, i_section: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveSection(Reference iSection)
                 | 
                 |     Removes a section or a plane from the spine curve.
@@ -389,6 +401,7 @@ class HybridShapeSpine(HybridShape):
 
         :param Reference i_section:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_spine.RemoveSection(i_section.com_object)
         # # # # Autogenerated comment: 
@@ -407,10 +420,10 @@ class HybridShapeSpine(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_start_point(self, i_point):
+    def set_start_point(self, i_point: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetStartPoint(Reference iPoint)
                 | 
                 |     Sets the start point of the spine curve.
@@ -426,6 +439,7 @@ class HybridShapeSpine(HybridShape):
 
         :param Reference i_point:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_spine.SetStartPoint(i_point.com_object)
         # # # # Autogenerated comment: 
@@ -445,4 +459,4 @@ class HybridShapeSpine(HybridShape):
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
-        return f'HybridShapeSpine(name="{self.name}")'
+        return f'HybridShapeSpine(name="{ self.name }")'
