@@ -1,6 +1,6 @@
 #! usr/bin/python3.6
 """
-    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
+    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
     .. warning::
         The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
@@ -18,7 +18,7 @@ from pycatia.knowledge_interfaces.length import Length
 class HybridShapeSweepCircle(HybridShapeSweep):
     """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
                 |     System.IDispatch
@@ -48,10 +48,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle = com_object
 
     @property
-    def canonical_detection(self):
+    def canonical_detection(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property CanonicalDetection() As long
                 | 
                 |     Returns or sets whether canonical surfaces of the swept surface are
@@ -61,12 +61,13 @@ class HybridShapeSweepCircle(HybridShapeSweep):
                 |     2 Detection of canonical surfaces is performed.
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_sweep_circle.CanonicalDetection
 
     @canonical_detection.setter
-    def canonical_detection(self, value):
+    def canonical_detection(self, value: int):
         """
         :param int value:
         """
@@ -74,10 +75,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.CanonicalDetection = value
 
     @property
-    def choice_no(self):
+    def choice_no(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ChoiceNo() As long
                 | 
                 |     Returns or sets the choice number, which corresponds to each solution of a
@@ -86,12 +87,13 @@ class HybridShapeSweepCircle(HybridShapeSweep):
                 |     four possible solutions.
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_sweep_circle.ChoiceNo
 
     @choice_no.setter
-    def choice_no(self, value):
+    def choice_no(self, value: int):
         """
         :param int value:
         """
@@ -99,10 +101,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.ChoiceNo = value
 
     @property
-    def context(self):
+    def context(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Context() As long
                 | 
                 |     Returns or sets the context on Sweep feature.
@@ -121,12 +123,13 @@ class HybridShapeSweepCircle(HybridShapeSweep):
                 |          Set oContext = Sweep.Context
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_sweep_circle.Context
 
     @context.setter
-    def context(self, value):
+    def context(self, value: int):
         """
         :param int value:
         """
@@ -134,21 +137,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.Context = value
 
     @property
-    def first_angle_law(self):
+    def first_angle_law(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property FirstAngleLaw() As Reference
                 | 
                 |     Returns or sets the first angle law useful in some circular sweep types.
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_sweep_circle.FirstAngleLaw)
 
     @first_angle_law.setter
-    def first_angle_law(self, value):
+    def first_angle_law(self, value: Reference):
         """
         :param Reference value:
         """
@@ -156,21 +160,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.FirstAngleLaw = value
 
     @property
-    def first_angle_law_inversion(self):
+    def first_angle_law_inversion(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property FirstAngleLawInversion() As long
                 | 
                 |     Returns or sets the first angle law inversion information.
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_sweep_circle.FirstAngleLawInversion
 
     @first_angle_law_inversion.setter
-    def first_angle_law_inversion(self, value):
+    def first_angle_law_inversion(self, value: int):
         """
         :param int value:
         """
@@ -178,21 +183,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.FirstAngleLawInversion = value
 
     @property
-    def first_guide_crv(self):
+    def first_guide_crv(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property FirstGuideCrv() As Reference
                 | 
                 |     Returns or sets the sweep operation first guide curve.
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_sweep_circle.FirstGuideCrv)
 
     @first_guide_crv.setter
-    def first_guide_crv(self, value):
+    def first_guide_crv(self, value: Reference):
         """
         :param Reference value:
         """
@@ -200,25 +206,26 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.FirstGuideCrv = value
 
     @property
-    def guide_deviation(self):
+    def guide_deviation(self) -> Length:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property GuideDeviation() As Length (Read Only)
                 | 
                 |     Returns the deviation value (length) from guide curves allowed during a
                 |     sweeping operation in order to smooth it.
 
         :return: Length
+        :rtype: Length
         """
 
         return Length(self.hybrid_shape_sweep_circle.GuideDeviation)
 
     @property
-    def guide_deviation_activity(self):
+    def guide_deviation_activity(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property GuideDeviationActivity() As boolean
                 | 
                 |     Returns or sets information whether a deviation from guide curves is
@@ -229,12 +236,13 @@ class HybridShapeSweepCircle(HybridShapeSweep):
                 |     if not specified).
 
         :return: bool
+        :rtype: bool
         """
 
         return self.hybrid_shape_sweep_circle.GuideDeviationActivity
 
     @guide_deviation_activity.setter
-    def guide_deviation_activity(self, value):
+    def guide_deviation_activity(self, value: bool):
         """
         :param bool value:
         """
@@ -242,10 +250,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.GuideDeviationActivity = value
 
     @property
-    def mode(self):
+    def mode(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Mode() As long
                 | 
                 |     Returns or sets the circular sweep mode.
@@ -270,12 +278,13 @@ class HybridShapeSweepCircle(HybridShapeSweep):
                 |     (CATGSMCircularSweep_GuideAndTangencyAndRadius)
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_sweep_circle.Mode
 
     @mode.setter
-    def mode(self, value):
+    def mode(self, value: int):
         """
         :param int value:
         """
@@ -283,21 +292,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.Mode = value
 
     @property
-    def radius_law(self):
+    def radius_law(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property RadiusLaw() As Reference
                 | 
                 |     Returns or sets the radius law feature.
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_sweep_circle.RadiusLaw)
 
     @radius_law.setter
-    def radius_law(self, value):
+    def radius_law(self, value: Reference):
         """
         :param Reference value:
         """
@@ -305,21 +315,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.RadiusLaw = value
 
     @property
-    def radius_law_inversion(self):
+    def radius_law_inversion(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property RadiusLawInversion() As long
                 | 
                 |     Returns or sets the radius law inversion information.
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_sweep_circle.RadiusLawInversion
 
     @radius_law_inversion.setter
-    def radius_law_inversion(self, value):
+    def radius_law_inversion(self, value: int):
         """
         :param int value:
         """
@@ -327,21 +338,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.RadiusLawInversion = value
 
     @property
-    def radius_law_type(self):
+    def radius_law_type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property RadiusLawType() As long
                 | 
                 |     Returns or sets the radius law type.
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_sweep_circle.RadiusLawType
 
     @radius_law_type.setter
-    def radius_law_type(self, value):
+    def radius_law_type(self, value: int):
         """
         :param int value:
         """
@@ -349,21 +361,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.RadiusLawType = value
 
     @property
-    def reference(self):
+    def reference(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Reference() As Reference
                 | 
                 |     Returns or sets the reference (functional curve or guide surface).
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_sweep_circle.Reference)
 
     @reference.setter
-    def reference(self, value):
+    def reference(self, value: Reference):
         """
         :param Reference value:
         """
@@ -371,21 +384,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.Reference = value
 
     @property
-    def second_angle_law(self):
+    def second_angle_law(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property SecondAngleLaw() As Reference
                 | 
                 |     Returns or sets the second angle law useful in some circular sweep types.
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_sweep_circle.SecondAngleLaw)
 
     @second_angle_law.setter
-    def second_angle_law(self, value):
+    def second_angle_law(self, value: Reference):
         """
         :param Reference value:
         """
@@ -393,21 +407,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.SecondAngleLaw = value
 
     @property
-    def second_angle_law_inversion(self):
+    def second_angle_law_inversion(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property SecondAngleLawInversion() As long
                 | 
                 |     Returns or sets the second angle law inversion information.
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_sweep_circle.SecondAngleLawInversion
 
     @second_angle_law_inversion.setter
-    def second_angle_law_inversion(self, value):
+    def second_angle_law_inversion(self, value: int):
         """
         :param int value:
         """
@@ -415,21 +430,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.SecondAngleLawInversion = value
 
     @property
-    def second_guide_crv(self):
+    def second_guide_crv(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property SecondGuideCrv() As Reference
                 | 
                 |     Returns or sets the sweep operation second guide curve.
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_sweep_circle.SecondGuideCrv)
 
     @second_guide_crv.setter
-    def second_guide_crv(self, value):
+    def second_guide_crv(self, value: Reference):
         """
         :param Reference value:
         """
@@ -437,10 +453,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.SecondGuideCrv = value
 
     @property
-    def smooth_activity(self):
+    def smooth_activity(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property SmoothActivity() As boolean
                 | 
                 |     Returns or sets information whether a sweeping operation is smoothed or
@@ -449,12 +465,13 @@ class HybridShapeSweepCircle(HybridShapeSweep):
                 |     not specified).
 
         :return: bool
+        :rtype: bool
         """
 
         return self.hybrid_shape_sweep_circle.SmoothActivity
 
     @smooth_activity.setter
-    def smooth_activity(self, value):
+    def smooth_activity(self, value: bool):
         """
         :param bool value:
         """
@@ -462,35 +479,37 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.SmoothActivity = value
 
     @property
-    def smooth_angle_threshold(self):
+    def smooth_angle_threshold(self) -> Angle:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property SmoothAngleThreshold() As Angle (Read Only)
                 | 
                 |     Returns the angular threshold.
 
         :return: Angle
+        :rtype: Angle
         """
 
         return Angle(self.hybrid_shape_sweep_circle.SmoothAngleThreshold)
 
     @property
-    def spine(self):
+    def spine(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Spine() As Reference
                 | 
                 |     Returns or sets the sweep operation spine (optional).
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_sweep_circle.Spine)
 
     @spine.setter
-    def spine(self, value):
+    def spine(self, value: Reference):
         """
         :param Reference value:
         """
@@ -498,21 +517,22 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.Spine = value
 
     @property
-    def third_guide_crv(self):
+    def third_guide_crv(self) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ThirdGuideCrv() As Reference
                 | 
                 |     Returns or sets the sweep operation third guide curve.
 
         :return: Reference
+        :rtype: Reference
         """
 
         return Reference(self.hybrid_shape_sweep_circle.ThirdGuideCrv)
 
     @third_guide_crv.setter
-    def third_guide_crv(self, value):
+    def third_guide_crv(self, value: Reference):
         """
         :param Reference value:
         """
@@ -520,10 +540,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         self.hybrid_shape_sweep_circle.ThirdGuideCrv = value
 
     @property
-    def trim_option(self):
+    def trim_option(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property TrimOption() As long
                 | 
                 |     Returns or sets the trim option status.
@@ -533,22 +553,23 @@ class HybridShapeSweepCircle(HybridShapeSweep):
                 |     1 Trim computed (CATGSMSweepTrimMode_On)
 
         :return: int
+        :rtype: int
         """
 
         return self.hybrid_shape_sweep_circle.TrimOption
 
     @trim_option.setter
-    def trim_option(self, value):
+    def trim_option(self, value: int):
         """
         :param int value:
         """
 
         self.hybrid_shape_sweep_circle.TrimOption = value
 
-    def get_angle(self, i_i):
+    def get_angle(self, i_i: int) -> Angle:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetAngle(long iI) As Angle
                 | 
                 |     Returns the angle values useful in some circular sweep
@@ -564,13 +585,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
 
         :param int i_i:
         :return: Angle
+        :rtype: Angle
         """
         return Angle(self.hybrid_shape_sweep_circle.GetAngle(i_i))
 
-    def get_angle_law_types(self, o_first_type, o_second_type):
+    def get_angle_law_types(self, o_first_type: int, o_second_type: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetAngleLawTypes(long oFirstType,
                 | long oSecondType)
                 | 
@@ -595,13 +617,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param int o_first_type:
         :param int o_second_type:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.GetAngleLawTypes(o_first_type, o_second_type)
 
-    def get_first_angle_law(self, o_elem1, o_elem2, ol_law_type):
+    def get_first_angle_law(self, o_elem1: Angle, o_elem2: Angle, ol_law_type: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetFirstAngleLaw(Angle oElem1,
                 | Angle oElem2,
                 | long olLawType)
@@ -622,6 +645,7 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param Angle o_elem2:
         :param int ol_law_type:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.GetFirstAngleLaw(o_elem1.com_object, o_elem2.com_object, ol_law_type)
         # # # # Autogenerated comment: 
@@ -640,10 +664,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_longitudinal_relimiters(self, op_ia_elem1, op_ia_elem2):
+    def get_longitudinal_relimiters(self, op_ia_elem1: Reference, op_ia_elem2: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetLongitudinalRelimiters(Reference opIAElem1,
                 | Reference opIAElem2)
                 | 
@@ -660,6 +684,7 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param Reference op_ia_elem1:
         :param Reference op_ia_elem2:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.GetLongitudinalRelimiters(op_ia_elem1.com_object, op_ia_elem2.com_object)
         # # # # Autogenerated comment: 
@@ -678,10 +703,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_nb_angle(self, o_ang):
+    def get_nb_angle(self, o_ang: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetNbAngle(long oAng)
                 | 
                 |     Retrieves the number of angles.
@@ -693,13 +718,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
 
         :param int o_ang:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.GetNbAngle(o_ang)
 
-    def get_nb_guide(self, o_num):
+    def get_nb_guide(self, o_num: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetNbGuide(long oNum)
                 | 
                 |     Retrieves the number of guide curves.
@@ -711,13 +737,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
 
         :param int o_num:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.GetNbGuide(o_num)
 
-    def get_nb_radius(self, o_rad):
+    def get_nb_radius(self, o_rad: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetNbRadius(long oRad)
                 | 
                 |     Retrieves the number of radii.
@@ -729,13 +756,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
 
         :param int o_rad:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.GetNbRadius(o_rad)
 
-    def get_radius(self, i_i):
+    def get_radius(self, i_i: int) -> Length:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetRadius(long iI) As Length
                 | 
                 |     Returns the radius value useful in some circular sweep
@@ -752,13 +780,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
 
         :param int i_i:
         :return: Length
+        :rtype: Length
         """
         return Length(self.hybrid_shape_sweep_circle.GetRadius(i_i))
 
-    def get_relimiters(self, op_ia_elem1, op_orient1, op_ia_elem2, op_orient2):
+    def get_relimiters(self, op_ia_elem1: Reference, op_orient1: int, op_ia_elem2: Reference, op_orient2: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetRelimiters(Reference opIAElem1,
                 | long opOrient1,
                 | Reference opIAElem2,
@@ -786,10 +815,9 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param Reference op_ia_elem2:
         :param int op_orient2:
         :return: None
+        :rtype: None
         """
-        return self.hybrid_shape_sweep_circle.GetRelimiters(op_ia_elem1.com_object,
-                                                            op_orient1,
-                                                            op_ia_elem2.com_object,
+        return self.hybrid_shape_sweep_circle.GetRelimiters(op_ia_elem1.com_object, op_orient1, op_ia_elem2.com_object,
                                                             op_orient2)
         # # # # Autogenerated comment: 
         # # some methods require a system service call as the methods expects a vb array object
@@ -807,10 +835,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_second_angle_law(self, o_elem1, o_elem2, ol_law_type):
+    def get_second_angle_law(self, o_elem1: Angle, o_elem2: Angle, ol_law_type: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetSecondAngleLaw(Angle oElem1,
                 | Angle oElem2,
                 | long olLawType)
@@ -831,6 +859,7 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param Angle o_elem2:
         :param int ol_law_type:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.GetSecondAngleLaw(o_elem1.com_object, o_elem2.com_object, ol_law_type)
         # # # # Autogenerated comment: 
@@ -849,10 +878,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_tangency_choice_no(self, o_no, o_shell_ori, o_guide_ori):
+    def get_tangency_choice_no(self, o_no: int, o_shell_ori: int, o_guide_ori: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetTangencyChoiceNo(long oNo,
                 | long oShellOri,
                 | long oGuideOri)
@@ -886,49 +915,53 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param int o_shell_ori:
         :param int o_guide_ori:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.GetTangencyChoiceNo(o_no, o_shell_ori, o_guide_ori)
 
-    def remove_angle(self):
+    def remove_angle(self) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveAngle()
                 | 
                 |     Removes an angle.
 
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.RemoveAngle()
 
-    def remove_guide(self):
+    def remove_guide(self) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveGuide()
                 | 
                 |     Removes a guide curve.
 
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.RemoveGuide()
 
-    def remove_radius(self):
+    def remove_radius(self) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveRadius()
                 | 
                 |     Removes a radius.
 
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.RemoveRadius()
 
-    def set_angle(self, i_i, i_elem):
+    def set_angle(self, i_i: int, i_elem: float) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAngle(long iI,
                 | double iElem)
                 | 
@@ -944,13 +977,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param int i_i:
         :param float i_elem:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.SetAngle(i_i, i_elem)
 
-    def set_angle_law_types(self, i_first_type, i_second_type):
+    def set_angle_law_types(self, i_first_type: int, i_second_type: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAngleLawTypes(long iFirstType,
                 | long iSecondType)
                 | 
@@ -976,13 +1010,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param int i_first_type:
         :param int i_second_type:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.SetAngleLawTypes(i_first_type, i_second_type)
 
-    def set_first_angle_law(self, i_elem1, i_elem2, il_law_type):
+    def set_first_angle_law(self, i_elem1: float, i_elem2: float, il_law_type: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetFirstAngleLaw(double iElem1,
                 | double iElem2,
                 | long ilLawType)
@@ -1003,13 +1038,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param float i_elem2:
         :param int il_law_type:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.SetFirstAngleLaw(i_elem1, i_elem2, il_law_type)
 
-    def set_guide_deviation(self, i_length):
+    def set_guide_deviation(self, i_length: float) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetGuideDeviation(double iLength)
                 | 
                 |     Sets the deviation value (length) from guide curves allowed during sweeping
@@ -1022,13 +1058,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
 
         :param float i_length:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.SetGuideDeviation(i_length)
 
-    def set_longitudinal_relimiters(self, ip_ia_elem1, ip_ia_elem2):
+    def set_longitudinal_relimiters(self, ip_ia_elem1: Reference, ip_ia_elem2: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLongitudinalRelimiters(Reference ipIAElem1,
                 | Reference ipIAElem2)
                 | 
@@ -1045,6 +1082,7 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param Reference ip_ia_elem1:
         :param Reference ip_ia_elem2:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.SetLongitudinalRelimiters(ip_ia_elem1.com_object, ip_ia_elem2.com_object)
         # # # # Autogenerated comment: 
@@ -1063,10 +1101,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_radius(self, i_i, i_radius):
+    def set_radius(self, i_i: int, i_radius: float) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetRadius(long iI,
                 | double iRadius)
                 | 
@@ -1083,13 +1121,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param int i_i:
         :param float i_radius:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.SetRadius(i_i, i_radius)
 
-    def set_relimiters(self, ip_ia_elem1, ip_orient1, ip_ia_elem2, ip_orient2):
+    def set_relimiters(self, ip_ia_elem1: Reference, ip_orient1: int, ip_ia_elem2: Reference, ip_orient2: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetRelimiters(Reference ipIAElem1,
                 | long ipOrient1,
                 | Reference ipIAElem2,
@@ -1117,12 +1156,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param Reference ip_ia_elem2:
         :param int ip_orient2:
         :return: None
+        :rtype: None
         """
-        return self.hybrid_shape_sweep_circle.SetRelimiters(ip_ia_elem1.com_object,
-                                                            ip_orient1,
-                                                            ip_ia_elem2.com_object,
-                                                            ip_orient2
-                                                            )
+        return self.hybrid_shape_sweep_circle.SetRelimiters(ip_ia_elem1.com_object, ip_orient1, ip_ia_elem2.com_object,
+                                                            ip_orient2)
         # # # # Autogenerated comment: 
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
@@ -1139,10 +1176,10 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_second_angle_law(self, i_elem1, i_elem2, il_law_type):
+    def set_second_angle_law(self, i_elem1: float, i_elem2: float, il_law_type: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetSecondAngleLaw(double iElem1,
                 | double iElem2,
                 | long ilLawType)
@@ -1163,13 +1200,14 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param float i_elem2:
         :param int il_law_type:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.SetSecondAngleLaw(i_elem1, i_elem2, il_law_type)
 
-    def set_smooth_angle_threshold(self, i_angle):
+    def set_smooth_angle_threshold(self, i_angle: float) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetSmoothAngleThreshold(double iAngle)
                 | 
                 |     Sets the angular threshold.
@@ -1181,18 +1219,19 @@ class HybridShapeSweepCircle(HybridShapeSweep):
 
         :param float i_angle:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.SetSmoothAngleThreshold(i_angle)
 
-    def set_tangency_choice_no(self, i_shell_ori, i_guide_ori, i_no):
+    def set_tangency_choice_no(self, i_shell_ori: int, i_guide_ori: int, i_no: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetTangencyChoiceNo(long iShellOri,
                 | long iGuideOri,
                 | long iNo)
                 | 
-                |     Sets a sequence which identifies a solution among all possibilities of a
+                |     Sets a sequence which identifies a solutionamong all possibilities of a
                 |     circular profile sweep tangent to a surface.
                 | 
                 |     Parameters:
@@ -1220,6 +1259,7 @@ class HybridShapeSweepCircle(HybridShapeSweep):
         :param int i_guide_ori:
         :param int i_no:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_sweep_circle.SetTangencyChoiceNo(i_shell_ori, i_guide_ori, i_no)
 
