@@ -34,22 +34,23 @@ class MacrosSettingAtt(SettingController):
         super().__init__(com_object)
         self.macros_setting_att = com_object
 
-    def get_default_macro_libraries(self):
+    def get_default_macro_libraries(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDefaultMacroLibraries() As CATSafeArrayVariant
                 | 
                 |     Returns the list of default macro libraries.
 
         :return: tuple
+        :rtype: tuple
         """
         return self.macros_setting_att.GetDefaultMacroLibraries()
 
-    def get_default_macro_libraries_info(self, admin_level, o_locked):
+    def get_default_macro_libraries_info(self, admin_level: str, o_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDefaultMacroLibrariesInfo(CATBSTR AdminLevel,
                 | CATBSTR oLocked) As boolean
                 | 
@@ -76,25 +77,27 @@ class MacrosSettingAtt(SettingController):
         :param str admin_level:
         :param str o_locked:
         :return: bool
+        :rtype: bool
         """
         return self.macros_setting_att.GetDefaultMacroLibrariesInfo(admin_level, o_locked)
 
-    def get_external_references(self):
+    def get_external_references(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetExternalReferences() As CATSafeArrayVariant
                 | 
                 |     Returns the list of external references.
 
         :return: tuple
+        :rtype: tuple
         """
         return self.macros_setting_att.GetExternalReferences()
 
-    def get_external_references_info(self, admin_level, o_locked):
+    def get_external_references_info(self, admin_level: str, o_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetExternalReferencesInfo(CATBSTR AdminLevel,
                 | CATBSTR oLocked) As boolean
                 | 
@@ -121,27 +124,29 @@ class MacrosSettingAtt(SettingController):
         :param str admin_level:
         :param str o_locked:
         :return: bool
+        :rtype: bool
         """
         return self.macros_setting_att.GetExternalReferencesInfo(admin_level, o_locked)
 
-    def get_language_editor(self, i_language):
+    def get_language_editor(self, i_language: int) -> str:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetLanguageEditor(CATScriptLanguage iLanguage) As
                 | CATBSTR
                 | 
                 |     Returns the editor path for the specified language.
 
-        :param CATScriptLanguage i_language:
+        :param int i_language:
         :return: str
+        :rtype: str
         """
-        return self.macros_setting_att.GetLanguageEditor(i_language.com_object)
+        return self.macros_setting_att.GetLanguageEditor(i_language)
 
-    def get_language_editor_info(self, admin_level, o_locked):
+    def get_language_editor_info(self, admin_level: str, o_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetLanguageEditorInfo(CATBSTR AdminLevel,
                 | CATBSTR oLocked) As boolean
                 | 
@@ -168,13 +173,14 @@ class MacrosSettingAtt(SettingController):
         :param str admin_level:
         :param str o_locked:
         :return: bool
+        :rtype: bool
         """
         return self.macros_setting_att.GetLanguageEditorInfo(admin_level, o_locked)
 
-    def set_default_macro_libraries(self, i_libraries):
+    def set_default_macro_libraries(self, i_libraries: tuple) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDefaultMacroLibraries(CATSafeArrayVariant
                 | iLibraries)
                 | 
@@ -182,6 +188,7 @@ class MacrosSettingAtt(SettingController):
 
         :param tuple i_libraries:
         :return: None
+        :rtype: None
         """
         return self.macros_setting_att.SetDefaultMacroLibraries(i_libraries)
         # # # # Autogenerated comment: 
@@ -200,10 +207,10 @@ class MacrosSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_default_macro_libraries_lock(self, i_locked):
+    def set_default_macro_libraries_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDefaultMacroLibrariesLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the default macro libraries setting.
@@ -221,6 +228,7 @@ class MacrosSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.macros_setting_att.SetDefaultMacroLibrariesLock(i_locked)
         # # # # Autogenerated comment: 
@@ -239,16 +247,17 @@ class MacrosSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_external_references(self, i_references):
+    def set_external_references(self, i_references: tuple) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetExternalReferences(CATSafeArrayVariant iReferences)
                 | 
                 |     Sets the list of external references.
 
         :param tuple i_references:
         :return: None
+        :rtype: None
         """
         return self.macros_setting_att.SetExternalReferences(i_references)
         # # # # Autogenerated comment: 
@@ -267,10 +276,10 @@ class MacrosSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_external_references_lock(self, i_locked):
+    def set_external_references_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetExternalReferencesLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the external references setting.
@@ -288,6 +297,7 @@ class MacrosSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.macros_setting_att.SetExternalReferencesLock(i_locked)
         # # # # Autogenerated comment: 
@@ -306,40 +316,26 @@ class MacrosSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_language_editor(self, i_language, i_editor_path):
+    def set_language_editor(self, i_language: int, i_editor_path: str) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLanguageEditor(CATScriptLanguage iLanguage,
                 | CATBSTR iEditorPath)
                 | 
                 |     Sets the editor path for the specified language.
 
-        :param CATScriptLanguage i_language:
+        :param int i_language:
         :param str i_editor_path:
         :return: None
+        :rtype: None
         """
-        return self.macros_setting_att.SetLanguageEditor(i_language.com_object, i_editor_path)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'set_language_editor'
-        # # vba_code = """
-        # # Public Function set_language_editor(macros_setting_att)
-        # #     Dim iLanguage (2)
-        # #     macros_setting_att.SetLanguageEditor iLanguage
-        # #     set_language_editor = iLanguage
-        # # End Function
-        # # """
+        return self.macros_setting_att.SetLanguageEditor(i_language, i_editor_path)
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
-
-    def set_language_editor_lock(self, i_locked):
+    def set_language_editor_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLanguageEditorLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the language editors setting.
@@ -357,6 +353,7 @@ class MacrosSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.macros_setting_att.SetLanguageEditorLock(i_locked)
         # # # # Autogenerated comment: 
