@@ -36,7 +36,7 @@ class DesignTable(Relation):
         self.design_table = com_object
 
     @property
-    def columns_nb(self):
+    def columns_nb(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -44,13 +44,14 @@ class DesignTable(Relation):
                 | 
                 |     Returns the nb of columns in the design table file.
 
-        :return: enum
+        :return: int
+        :rtype: int
         """
 
         return self.design_table.ColumnsNb
 
     @property
-    def configuration(self):
+    def configuration(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -59,21 +60,22 @@ class DesignTable(Relation):
                 |     Returns or sets the current configuration. Legal values: 1 to
                 |     ConfigurationsNb.
 
-        :return: enum
+        :return: int
+        :rtype: int
         """
 
         return self.design_table.Configuration
 
     @configuration.setter
-    def configuration(self, value):
+    def configuration(self, value: int):
         """
-        :param enum value:
+        :param int value:
         """
 
         self.design_table.Configuration = value
 
     @property
-    def configurations_nb(self):
+    def configurations_nb(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -81,13 +83,14 @@ class DesignTable(Relation):
                 | 
                 |     Returns the number of design table configurations.
 
-        :return: enum
+        :return: int
+        :rtype: int
         """
 
         return self.design_table.ConfigurationsNb
 
     @property
-    def copy_mode(self):
+    def copy_mode(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -97,12 +100,13 @@ class DesignTable(Relation):
                 |     inside the CATIA model.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.design_table.CopyMode
 
     @copy_mode.setter
-    def copy_mode(self, value):
+    def copy_mode(self, value: bool):
         """
         :param bool value:
         """
@@ -110,7 +114,7 @@ class DesignTable(Relation):
         self.design_table.CopyMode = value
 
     @property
-    def file_path(self):
+    def file_path(self) -> str:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -119,19 +123,20 @@ class DesignTable(Relation):
                 |     Returns or sets the path of the design table (read/write property).
 
         :return: str
+        :rtype: str
         """
 
         return self.design_table.FilePath
 
     @file_path.setter
-    def file_path(self, value):
+    def file_path(self, value: str):
         """
         :param str value:
         """
 
         self.design_table.FilePath = value
 
-    def add_association(self, i_parameter, i_sheet_column):
+    def add_association(self, i_parameter: 'Parameter', i_sheet_column: str) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -154,6 +159,7 @@ class DesignTable(Relation):
         :param Parameter i_parameter:
         :param str i_sheet_column:
         :return: None
+        :rtype: None
         """
         return self.design_table.AddAssociation(i_parameter.com_object, i_sheet_column)
         # # # # Autogenerated comment: 
@@ -172,7 +178,7 @@ class DesignTable(Relation):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def add_new_row(self):
+    def add_new_row(self) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -190,10 +196,11 @@ class DesignTable(Relation):
                 |         S_OK if succeeded, E_FAIL else.
 
         :return: None
+        :rtype: None
         """
         return self.design_table.AddNewRow()
 
-    def cell_as_string(self, i_row, i_column):
+    def cell_as_string(self, i_row: int, i_column: int) -> str:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -209,13 +216,14 @@ class DesignTable(Relation):
                 |         iColumn
                 |             the index of the column where the cell is located.
 
-        :param enum i_row:
-        :param enum i_column:
+        :param int i_row:
+        :param int i_column:
         :return: str
+        :rtype: str
         """
         return self.design_table.CellAsString(i_row, i_column)
 
-    def remove_association(self, i_sheet_column):
+    def remove_association(self, i_sheet_column: str) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -231,10 +239,11 @@ class DesignTable(Relation):
 
         :param str i_sheet_column:
         :return: None
+        :rtype: None
         """
         return self.design_table.RemoveAssociation(i_sheet_column)
 
-    def synchronize(self):
+    def synchronize(self) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -245,6 +254,7 @@ class DesignTable(Relation):
                 |     content
 
         :return: None
+        :rtype: None
         """
         return self.design_table.Synchronize()
 
