@@ -49,7 +49,7 @@ class RealParam(Parameter):
         self.real_param = com_object
 
     @property
-    def maximum_tolerance(self):
+    def maximum_tolerance(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -67,12 +67,13 @@ class RealParam(Parameter):
                 |          End If
 
         :return: float
+        :rtype: float
         """
 
         return self.real_param.MaximumTolerance
 
     @maximum_tolerance.setter
-    def maximum_tolerance(self, value):
+    def maximum_tolerance(self, value: float):
         """
         :param float value:
         """
@@ -80,7 +81,7 @@ class RealParam(Parameter):
         self.real_param.MaximumTolerance = value
 
     @property
-    def minimum_tolerance(self):
+    def minimum_tolerance(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -98,12 +99,13 @@ class RealParam(Parameter):
                 |          End If
 
         :return: float
+        :rtype: float
         """
 
         return self.real_param.MinimumTolerance
 
     @minimum_tolerance.setter
-    def minimum_tolerance(self, value):
+    def minimum_tolerance(self, value: float):
         """
         :param float value:
         """
@@ -111,7 +113,7 @@ class RealParam(Parameter):
         self.real_param.MinimumTolerance = value
 
     @property
-    def range_max(self):
+    def range_max(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -130,12 +132,13 @@ class RealParam(Parameter):
                 |          End If
 
         :return: float
+        :rtype: float
         """
 
         return self.real_param.RangeMax
 
     @range_max.setter
-    def range_max(self, value):
+    def range_max(self, value: float):
         """
         :param float value:
         """
@@ -143,7 +146,7 @@ class RealParam(Parameter):
         self.real_param.RangeMax = value
 
     @property
-    def range_max_validity(self):
+    def range_max_validity(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -160,12 +163,13 @@ class RealParam(Parameter):
                 |         the upper bound cannot be reached
 
         :return: int
+        :rtype: int
         """
 
         return self.real_param.RangeMaxValidity
 
     @range_max_validity.setter
-    def range_max_validity(self, value):
+    def range_max_validity(self, value: int):
         """
         :param int value:
         """
@@ -173,7 +177,7 @@ class RealParam(Parameter):
         self.real_param.RangeMaxValidity = value
 
     @property
-    def range_min(self):
+    def range_min(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -192,12 +196,13 @@ class RealParam(Parameter):
                 |          End If
 
         :return: float
+        :rtype: float
         """
 
         return self.real_param.RangeMin
 
     @range_min.setter
-    def range_min(self, value):
+    def range_min(self, value: float):
         """
         :param float value:
         """
@@ -205,7 +210,7 @@ class RealParam(Parameter):
         self.real_param.RangeMin = value
 
     @property
-    def range_min_validity(self):
+    def range_min_validity(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -222,12 +227,13 @@ class RealParam(Parameter):
                 |         the lower bound cannot be reached
 
         :return: int
+        :rtype: int
         """
 
         return self.real_param.RangeMinValidity
 
     @range_min_validity.setter
-    def range_min_validity(self, value):
+    def range_min_validity(self, value: int):
         """
         :param int value:
         """
@@ -235,7 +241,7 @@ class RealParam(Parameter):
         self.real_param.RangeMinValidity = value
 
     @property
-    def value(self):
+    def value(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -254,19 +260,20 @@ class RealParam(Parameter):
                 |          End If
 
         :return: float
+        :rtype: float
         """
 
         return self.real_param.Value
 
     @value.setter
-    def value(self, value):
+    def value(self, value: float):
         """
         :param float value:
         """
 
         self.real_param.Value = value
 
-    def get_enumerate_values(self, o_safe_array):
+    def get_enumerate_values(self, o_safe_array: tuple) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -287,6 +294,7 @@ class RealParam(Parameter):
 
         :param tuple o_safe_array:
         :return: None
+        :rtype: None
         """
         return self.real_param.GetEnumerateValues(o_safe_array)
         # # # # Autogenerated comment: 
@@ -305,7 +313,7 @@ class RealParam(Parameter):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_enumerate_values_size(self):
+    def get_enumerate_values_size(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -314,10 +322,11 @@ class RealParam(Parameter):
                 |     Returns the number of enumerate values.
 
         :return: int
+        :rtype: int
         """
         return self.real_param.GetEnumerateValuesSize()
 
-    def is_equal_to(self, i_value_to_compare):
+    def is_equal_to(self, i_value_to_compare: float) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -345,10 +354,11 @@ class RealParam(Parameter):
 
         :param float i_value_to_compare:
         :return: bool
+        :rtype: bool
         """
         return self.real_param.IsEqualTo(i_value_to_compare)
 
-    def set_enumerate_values(self, i_safe_array):
+    def set_enumerate_values(self, i_safe_array: tuple) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -359,6 +369,7 @@ class RealParam(Parameter):
 
         :param tuple i_safe_array:
         :return: None
+        :rtype: None
         """
         return self.real_param.SetEnumerateValues(i_safe_array)
         # # # # Autogenerated comment: 
@@ -377,7 +388,7 @@ class RealParam(Parameter):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def suppress_enumerate_values(self):
+    def suppress_enumerate_values(self) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -386,6 +397,7 @@ class RealParam(Parameter):
                 |     Resets the status of the object to a single value object.
 
         :return: None
+        :rtype: None
         """
         return self.real_param.SuppressEnumerateValues()
 
