@@ -11,6 +11,7 @@
 
 from pycatia.mec_mod_interfaces.hybrid_body import HybridBody
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class HybridBodies(Collection):
@@ -34,7 +35,7 @@ class HybridBodies(Collection):
         self.hybrid_bodies = com_object
         self.child_object = child_object
 
-    def add(self):
+    def add(self) -> HybridBody:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -53,13 +54,14 @@ class HybridBodies(Collection):
                 |          Set NewPartBody = rootPart.Bodies.AddPartBody()
 
         :return: HybridBody
+        :rtype: HybridBody
         """
         return HybridBody(self.hybrid_bodies.Add())
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> HybridBody:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func Item(CATVariant iIndex) As HybridBody
                 | 
                 |     Returns a body using its index or its name from the Bodies
@@ -87,8 +89,9 @@ class HybridBodies(Collection):
                 |          Set ThisHybridBody = hybridBodyColl.Item(5)
                 |          Set ThatHybridBody = hybridBodyColl.Item("MyHybridBody")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: HybridBody
+        :rtype: HybridBody
         """
         return HybridBody(self.hybrid_bodies.Item(i_index))
 
