@@ -13,7 +13,6 @@ from pycatia.mec_mod_interfaces.face import Face
 
 
 class PlanarFace(Face):
-
     """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -65,7 +64,9 @@ class PlanarFace(Face):
                 |      element",true)
                 |      if (Status = "cancel") then Exit Sub
                 |      Set PartingElement = Selection.Item(1).Value
-                |      Set Draft = ShapeFactory.AddNewDraft(FaceToDraft,NeutralFace,0,PartingElement,0.0,0.0,1.0,0,5.0,0)
+                |      Set Draft = ShapeFactory.AddNewDraft(
+                |                      FaceToDraft,NeutralFace,0,PartingElement,0.0,0.0,1.0,0,5.0,0
+                |                  )
                 |      Set DraftDomains = Draft.DraftDomains
                 |      Set DraftDomain = DraftDomains.Item(1)
                 |      DraftDomain.SetPullingDirection 0.0, 0.0,1.0
@@ -77,10 +78,10 @@ class PlanarFace(Face):
         super().__init__(com_object)
         self.planar_face = com_object
 
-    def get_first_axis(self, o_first_axis=None):
+    def get_first_axis(self, o_first_axis: tuple) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetFirstAxis(CATSafeArrayVariant oFirstAxis)
                 | 
                 |     Returns the planar face first axis
@@ -96,6 +97,7 @@ class PlanarFace(Face):
 
         :param tuple o_first_axis:
         :return: None
+        :rtype: None
         """
         return self.planar_face.GetFirstAxis(o_first_axis)
         # # # # Autogenerated comment: 
@@ -114,10 +116,10 @@ class PlanarFace(Face):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_origin(self, o_origin=None):
+    def get_origin(self, o_origin: tuple) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                 | 
                 |     Returns the origin of the planar face.
@@ -133,6 +135,7 @@ class PlanarFace(Face):
 
         :param tuple o_origin:
         :return: None
+        :rtype: None
         """
         return self.planar_face.GetOrigin(o_origin)
         # # # # Autogenerated comment: 
@@ -151,10 +154,10 @@ class PlanarFace(Face):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_second_axis(self, o_second_axis=None):
+    def get_second_axis(self, o_second_axis: tuple) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetSecondAxis(CATSafeArrayVariant oSecondAxis)
                 | 
                 |     Returns the planar face second axis.
@@ -170,6 +173,7 @@ class PlanarFace(Face):
 
         :param tuple o_second_axis:
         :return: None
+        :rtype: None
         """
         return self.planar_face.GetSecondAxis(o_second_axis)
         # # # # Autogenerated comment: 
@@ -189,4 +193,4 @@ class PlanarFace(Face):
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
-        return f'PlanarFace(name="{ self.name }")'
+        return f'PlanarFace(name="{self.name}")'
