@@ -10,6 +10,7 @@
 """
 from pycatia.sketcher_interfaces.geometry_2D import Geometry2D
 from pycatia.sketcher_interfaces.point_2D import Point2D
+from pycatia.system_interfaces.system_service import SystemService
 
 
 class Curve2D(Geometry2D):
@@ -32,13 +33,13 @@ class Curve2D(Geometry2D):
 
     def __init__(self, com_object):
         super().__init__(com_object)
-        self.curve2_d = com_object
+        self.curve_2d = com_object
 
     @property
-    def continuity(self):
+    def continuity(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Continuity() As short (Read Only)
                 | 
                 |     Returns the highest level of geometric continuity the curve
@@ -49,16 +50,17 @@ class Curve2D(Geometry2D):
                 |         oLevel
                 |             The maximum geometric continuity level
 
-        :return: enum
+        :return: int
+        :rtype: int
         """
 
-        return self.curve2_d.Continuity
+        return self.curve_2d.Continuity
 
     @property
-    def end_point(self):
+    def end_point(self) -> Point2D:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property EndPoint() As Point2D
                 | 
                 |     Returns the end point of the curve. The end point is decided with respect
@@ -70,23 +72,24 @@ class Curve2D(Geometry2D):
                 |             The end point of the curve
 
         :return: Point2D
+        :rtype: Point2D
         """
 
-        return Point2D(self.curve2_d.EndPoint)
+        return Point2D(self.curve_2d.EndPoint)
 
     @end_point.setter
-    def end_point(self, point_2D):
+    def end_point(self, value: Point2D):
         """
-        :param Point2D point_2D:
+        :param Point2D value:
         """
 
-        self.curve2_d.EndPoint = point_2D.com_object
+        self.curve_2d.EndPoint = value
 
     @property
-    def period(self):
+    def period(self) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Period() As double (Read Only)
                 | 
                 |     Returns the period of a periodic curve.
@@ -97,15 +100,16 @@ class Curve2D(Geometry2D):
                 |             The period of the curve.
 
         :return: float
+        :rtype: float
         """
 
-        return self.curve2_d.Period
+        return self.curve_2d.Period
 
     @property
-    def start_point(self):
+    def start_point(self) -> Point2D:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property StartPoint() As Point2D
                 | 
                 |     Returns the start point of the curve. The start point is decided with
@@ -118,22 +122,23 @@ class Curve2D(Geometry2D):
                 |             The start point of the curve
 
         :return: Point2D
+        :rtype: Point2D
         """
 
-        return Point2D(self.curve2_d.StartPoint)
+        return Point2D(self.curve_2d.StartPoint)
 
     @start_point.setter
-    def start_point(self, point_2D):
+    def start_point(self, value: Point2D):
         """
-        :param Point2D point_2D:
+        :param Point2D value:
         """
 
-        self.curve2_d.StartPoint = point_2D.com_object
+        self.curve_2d.StartPoint = value
 
-    def get_curvature(self, i_param, o_curvature):
+    def get_curvature(self, i_param: float) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetCurvature(double iParam,
                 | CATSafeArrayVariant oCurvature)
                 | 
@@ -151,30 +156,26 @@ class Curve2D(Geometry2D):
                 |             parameter.
 
         :param float i_param:
-        :param tuple o_curvature:
-        :return: None
+        :return: tuple
+        :rtype: tuple
         """
-        return self.curve2_d.GetCurvature(i_param, o_curvature)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_curvature'
-        # # vba_code = """
-        # # Public Function get_curvature(curve2_d)
-        # #     Dim iParam (2)
-        # #     curve2_d.GetCurvature iParam
-        # #     get_curvature = iParam
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_curvature'
+        vba_code = """
+        Public Function get_curvature(curve2_d, i_param)
+            Dim oCurvature (2)
+            curve2_d.GetCurvature i_param oCurvature
+            get_curvature = oCurvature
+        End Function
+        """
 
-    def get_derivatives(self, i_param, o_derivative):
+        system_service = SystemService(self.application.SystemService)
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object, i_param])
+
+    def get_derivatives(self, i_param: float) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetDerivatives(double iParam,
                 | CATSafeArrayVariant oDerivative)
                 | 
@@ -193,30 +194,26 @@ class Curve2D(Geometry2D):
                 |             Third degree derivative.
 
         :param float i_param:
-        :param tuple o_derivative:
-        :return: None
+        :return: tuple
+        :rtype: tuple
         """
-        return self.curve2_d.GetDerivatives(i_param, o_derivative)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_derivatives'
-        # # vba_code = """
-        # # Public Function get_derivatives(curve2_d)
-        # #     Dim iParam (2)
-        # #     curve2_d.GetDerivatives iParam
-        # #     get_derivatives = iParam
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_derivatives'
+        vba_code = """
+        Public Function get_derivatives(curve2_d, i_param)
+            Dim oDerivative(2)
+            curve2_d.GetDerivatives iParam oDerivative
+            get_derivatives = oDerivative
+        End Function
+        """
 
-    def get_end_points(self, o_end_points):
+        system_service = SystemService(self.application.SystemService)
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object, i_param])
+
+    def get_end_points(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetEndPoints(CATSafeArrayVariant oEndPoints)
                 | 
                 |     Returns the end-points of the curve. The start point and the end point are
@@ -234,30 +231,26 @@ class Curve2D(Geometry2D):
                 |         oEndPoints[3]
                 |             The y coordinate of the end point
 
-        :param tuple o_end_points:
-        :return: None
+        :return: tuple
+        :rtype: tuple
         """
-        return self.curve2_d.GetEndPoints(o_end_points)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_end_points'
-        # # vba_code = """
-        # # Public Function get_end_points(curve2_d)
-        # #     Dim oEndPoints (2)
-        # #     curve2_d.GetEndPoints oEndPoints
-        # #     get_end_points = oEndPoints
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_end_points'
+        vba_code = """
+        Public Function get_end_points(curve2_d)
+            Dim oEndPoints (3)
+            curve2_d.GetEndPoints oEndPoints
+            get_end_points = oEndPoints
+        End Function
+        """
 
-    def get_length_at_param(self, i_from_param, i_to_param):
+        system_service = SystemService(self.application.SystemService)
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_length_at_param(self, i_from_param: float, i_to_param: float) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetLengthAtParam(double iFromParam,
                 | double iToParam) As double
                 | 
@@ -278,13 +271,14 @@ class Curve2D(Geometry2D):
         :param float i_from_param:
         :param float i_to_param:
         :return: float
+        :rtype: float
         """
-        return self.curve2_d.GetLengthAtParam(i_from_param, i_to_param)
+        return self.curve_2d.GetLengthAtParam(i_from_param, i_to_param)
 
-    def get_param_at_length(self, i_from_param, i_length):
+    def get_param_at_length(self, i_from_param: float, i_length: float) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetParamAtLength(double iFromParam,
                 | double iLength) As double
                 | 
@@ -308,13 +302,14 @@ class Curve2D(Geometry2D):
         :param float i_from_param:
         :param float i_length:
         :return: float
+        :rtype: float
         """
-        return self.curve2_d.GetParamAtLength(i_from_param, i_length)
+        return self.curve_2d.GetParamAtLength(i_from_param, i_length)
 
-    def get_param_extents(self, o_params):
+    def get_param_extents(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetParamExtents(CATSafeArrayVariant oParams)
                 | 
                 |     Returns the parametric extents of the curve. This is the parametric
@@ -329,30 +324,26 @@ class Curve2D(Geometry2D):
                 |             The parameter associated with the end point of the
                 |             curve
 
-        :param tuple o_params:
-        :return: None
+        :return: tuple
+        :rtype: tuple
         """
-        return self.curve2_d.GetParamExtents(o_params)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_param_extents'
-        # # vba_code = """
-        # # Public Function get_param_extents(curve2_d)
-        # #     Dim oParams (2)
-        # #     curve2_d.GetParamExtents oParams
-        # #     get_param_extents = oParams
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_param_extents'
+        vba_code = """
+        Public Function get_param_extents(curve2_d)
+            Dim oParams(1)
+            curve2_d.GetParamExtents oParams
+            get_param_extents = oParams
+        End Function
+        """
 
-    def get_point_at_param(self, i_param, o_point):
+        system_service = SystemService(self.application.SystemService)
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_point_at_param(self, i_param: float) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetPointAtParam(double iParam,
                 | CATSafeArrayVariant oPoint)
                 | 
@@ -368,30 +359,26 @@ class Curve2D(Geometry2D):
                 |             point.
 
         :param float i_param:
-        :param tuple o_point:
-        :return: None
+        :return: tuple
+        :rtype: tuple
         """
-        return self.curve2_d.GetPointAtParam(i_param, o_point)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_point_at_param'
-        # # vba_code = """
-        # # Public Function get_point_at_param(curve2_d)
-        # #     Dim iParam (2)
-        # #     curve2_d.GetPointAtParam iParam
-        # #     get_point_at_param = iParam
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_point_at_param'
+        vba_code = """
+        Public Function get_point_at_param(curve2_d, i_param)
+            Dim oPoint (1)
+            curve2_d.GetPointAtParam i_param oPoint
+            get_point_at_param = oPoint
+        End Function
+        """
 
-    def get_range_box(self, o_bound_point):
+        system_service = SystemService(self.application.SystemService)
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object, i_param])
+
+    def get_range_box(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetRangeBox(CATSafeArrayVariant oBoundPoint)
                 | 
                 |     Returns the range box (or bounding box) of the object
@@ -409,30 +396,26 @@ class Curve2D(Geometry2D):
                 |         oBoundPoint[3]
                 |             The maximum y point of the box
 
-        :param tuple o_bound_point:
-        :return: None
+        :return: tuple
+        :rtype: tuple
         """
-        return self.curve2_d.GetRangeBox(o_bound_point)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_range_box'
-        # # vba_code = """
-        # # Public Function get_range_box(curve2_d)
-        # #     Dim oBoundPoint (2)
-        # #     curve2_d.GetRangeBox oBoundPoint
-        # #     get_range_box = oBoundPoint
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_range_box'
+        vba_code = """
+        Public Function get_range_box(curve2_d)
+            Dim oBoundPoint(3)
+            curve2_d.GetRangeBox oBoundPoint
+            get_range_box = oBoundPoint
+        End Function
+        """
 
-    def get_tangent(self, i_param, o_tangency):
+        system_service = SystemService(self.application.SystemService)
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_tangent(self, i_param: float) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetTangent(double iParam,
                 | CATSafeArrayVariant oTangency)
                 | 
@@ -447,31 +430,27 @@ class Curve2D(Geometry2D):
                 |             The X and Y coordinates of the unit-vector tangent at the specified
                 |             parameter.
 
-        :param float i_param:
-        :param tuple o_tangency:
+        :i_param: float
         :return: None
+        :rtype: None
         """
-        return self.curve2_d.GetTangent(i_param, o_tangency)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_tangent'
-        # # vba_code = """
-        # # Public Function get_tangent(curve2_d)
-        # #     Dim iParam (2)
-        # #     curve2_d.GetTangent iParam
-        # #     get_tangent = iParam
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_tangent'
+        vba_code = """
+        Public Function get_tangent(curve2_d, i_param)
+            Dim oTangency(1)
+            curve2_d.GetTangent i_param oTangency
+            get_tangent = oTangency
+        End Function
+        """
 
-    def is_periodic(self):
+        system_service = SystemService(self.application.SystemService)
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object, i_param])
+
+    def is_periodic(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func IsPeriodic() As boolean
                 | 
                 |     Specifies whether a curve is periodic or not.
@@ -482,8 +461,9 @@ class Curve2D(Geometry2D):
                 |             Returns true if the curve is periodic.
 
         :return: bool
+        :rtype: bool
         """
-        return self.curve2_d.IsPeriodic()
+        return self.curve_2d.IsPeriodic()
 
     def __repr__(self):
         return f'Curve2D(name="{self.name}")'
